@@ -10,17 +10,18 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: scriptLibInfo.php 5983 2013-05-11 13:16:53Z fishbone $
+ * @version    SVN: $Id: scriptLibInfo.php 6068 2013-06-03 01:52:34Z fishbone $
  * @link       http://www.magic3.org
  */
 class ScriptLibInfo
 {
 	private static $jQueryVer = 1.8;			// デフォルトで使用するjQueryのバージョン
-	private static $jQueryVersionArray = array(	'1.6' => 'jquery-1.6.4.min.js',// jQueryバージョン
-												'1.7' => 'jquery-1.7.2.min.js',
-												'1.8' => 'jquery-1.8.3.min.js',
-												'1.9' => 'jquery-1.9.1.min.js',
-												'2.0' => 'jquery-2.0.0.min.js');
+	private static $jQueryVersionArray = array(	'1.6'	=> 'jquery-1.6.4.min.js',// jQueryバージョン
+												'1.7'	=> 'jquery-1.7.2.min.js',
+												'1.8'	=> 'jquery-1.8.3.min.js',
+												'1.9'	=> 'jquery-1.9.1.min.js',
+												'1.10'	=> 'jquery-1.10.0.min.js',
+												'2.0'	=> 'jquery-2.0.1.min.js');
 	private static $wysiwygEditorType = 'fckeditor';		// WYSIWYGエディタータイプ
 	
 	// Javascriptライブラリ(DBでの設定値)
@@ -68,6 +69,7 @@ class ScriptLibInfo
 	const LIB_JQUERY_MOUSEWHEEL		= 'jquery.mousewheel';
 	const LIB_JQUERY_CLOUDCAROUSEL	= 'jquery.cloudcarousel';
 //	const LIB_JQUERY_JQEASYPANEL	= 'jquery.jqeasypanel';
+	const LIB_JQUERY_SCROLLTO		= 'jquery.scrollto';
 	
 	// CodeMirror
 	const LIB_CODEMIRROR_JAVASCRIPT	= 'codemirror.javascript';		// CodeMirror Javascript
@@ -88,6 +90,7 @@ class ScriptLibInfo
 	const JQUERY_MOUSEWHEEL_VER		= '3.0.6';
 	const JQUERY_CLOUDCAROUSEL_VER	= '1.0.5';
 //	const JQUERY_JQEASYPANEL_VER	= '1.0';
+	const JQUERY_SCROLLTO_VER		= '1.4.3.1';
 	// その他ライブラリバージョン
 	const CODEMIRROR_VER			= '3.1';
 	
@@ -148,12 +151,14 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.7/jquery.jqplot.min.css';
 	const JQUERY_YOUTUBEPLAYER_FILENAME	= 'jquery/jquery.youtube.player.js';
 	const JQUERY_JSTREE_FILENAME		= 'jquery/jstree/jquery.jstree.js';
 //	const JQUERY_IFRAME_FILENAME		= 'jquery/jquery.iframe-auto-height.plugin.1.5.0.min.js';
-	const JQUERY_IFRAME_FILENAME		= 'jquery/jquery.iframe-auto-height.plugin.1.7.1.min.js';
+//	const JQUERY_IFRAME_FILENAME		= 'jquery/jquery.iframe-auto-height.plugin.1.7.1.min.js';
+	const JQUERY_IFRAME_FILENAME		= 'jquery/jquery.iframe-auto-height.plugin.1.9.1.min.js';
 	const JQUERY_RATY_FILENAME			= 'jquery/raty/jquery.raty.js';
 	const JQUERY_MOUSEWHEEL_FILENAME	= 'jquery/jquery.mousewheel.js';
 	const JQUERY_CLOUDCAROUSEL_FILENAME	= 'jquery/cloud-carousel.1.0.5.min.js';
 //	const JQUERY_JQEASYPANEL_FILENAME	= 'jquery/jquery.jqEasyPanel.js';
 //	const JQUERY_JQEASYPANEL_CSS		= 'jquery/jqeasypanel.css';
+	const JQUERY_SCROLLTO_FILENAME		= 'jquery/jquery.scrollTo-1.4.3.1-min.js';
 	
 	// ライブラリの公式サイトのURL
 	const JQUERY_JCAROUSEL_URL			= 'http://sorgalla.com/projects/jcarousel/';
@@ -171,6 +176,7 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.7/jquery.jqplot.min.css';
 	const JQUERY_MOUSEWHEEL_URL			= 'https://github.com/brandonaaron/jquery-mousewheel';
 	const JQUERY_CLOUDCAROUSEL_URL		= 'http://www.professorcloud.com/mainsite/carousel.htm';
 //	const JQUERY_JQEASYPANEL_URL		= 'http://www.jqeasy.com/';
+	const JQUERY_SCROLLTO_URL			= 'http://flesler.blogspot.jp/2007/10/jqueryscrollto.html';
 	const CODEMIRROR_URL				= 'http://codemirror.net/';		// CodeMirror
 	
 	// ディレクトリ名
@@ -293,12 +299,12 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.7/jquery.jqplot.min.css';
 					// jQueryライブラリ
 					self::LIB_JQUERY_EASING			=>	array(	'script' 	=> array(self::JQUERY_EASING_FILENAME)),		// jquery.easing用のファイル
 					self::LIB_JQUERY_JCAROUSEL		=>	array(	'script' 	=> array(self::JQUERY_JCAROUSEL_FILENAME),
-																'url'		=>	self::JQUERY_JCAROUSEL_URL,
-																'version'	=>	self::JQUERY_JCAROUSEL_VER),			// jquery.jcarousel用のファイル
+																'url'		=> self::JQUERY_JCAROUSEL_URL,
+																'version'	=> self::JQUERY_JCAROUSEL_VER),			// jquery.jcarousel用のファイル
 					self::LIB_JQUERY_THICKBOX		=>	array(	'script' 	=> array(self::JQUERY_THICKBOX_FILENAME),// jquery.thickbox用のファイル
 																'css'		=> array(self::JQUERY_THICKBOX_CSS),
-																'url'		=>	self::JQUERY_THICKBOX_URL,
-																'version'	=>	self::JQUERY_THICKBOX_VER),
+																'url'		=> self::JQUERY_THICKBOX_URL,
+																'version'	=> self::JQUERY_THICKBOX_VER),
 //					self::LIB_JQUERY_JSHOTKEYS		=>	array(	'script' 	=> array(self::JQUERY_JSHOTKEYS_FILENAME)),	// jquery.js-hotkeys用のファイル
 					self::LIB_JQUERY_CYCLE			=>	array(	'script' 	=> array(self::JQUERY_CYCLE_FILENAME)),		// jquery.cycle用のファイル
 					self::LIB_JQUERY_CODEPRESS		=>	array(	'script' 	=> array(self::JQUERY_CODEPRESS_FILENAME)),	// jquery.codepress用のファイル
@@ -316,50 +322,53 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.7/jquery.jqplot.min.css';
 					self::LIB_JQUERY_FORMAT			=>	array(	'script' 	=> array(self::JQUERY_FORMAT_FILENAME)),
 					self::LIB_JQUERY_FORMTIPS		=>	array(	'script' 	=> array(self::JQUERY_FORMTIPS_FILENAME)),
 					self::LIB_JQUERY_FACEBOX		=>	array(	'script' 	=> array(self::JQUERY_FACEBOX_FILENAME),	// jquery.facebox用のファイル
-																'css'		=>	array(self::JQUERY_FACEBOX_CSS),
-																'url'		=>	self::JQUERY_FACEBOX_URL),
+																'css'		=> array(self::JQUERY_FACEBOX_CSS),
+																'url'		=> self::JQUERY_FACEBOX_URL),
 					self::LIB_JQUERY_CURVYCORNERS	=> array(	'script'	=> array(self::JQUERY_CURVYCORNERS_FILENAME),
-																'url'		=>	self::JQUERY_CURVYCORNERS_URL),
+																'url'		=> self::JQUERY_CURVYCORNERS_URL),
 					self::LIB_JQUERY_PRETTYPHOTO	=>	array(	'script' 	=> array(self::JQUERY_PRETTYPHOTO_FILENAME),	// jquery.prettyPhoto用のファイル
-																'css'		=>	array(self::JQUERY_PRETTYPHOTO_CSS),
-																'url'		=>	self::JQUERY_PRETTYPHOTO_URL,
-																'version'	=>	self::JQUERY_PRETTYPHOTO_VER),
+																'css'		=> array(self::JQUERY_PRETTYPHOTO_CSS),
+																'url'		=> self::JQUERY_PRETTYPHOTO_URL,
+																'version'	=> self::JQUERY_PRETTYPHOTO_VER),
 					self::LIB_JQUERY_QTIP			=>	array(	'script' 	=> array(self::JQUERY_QTIP_FILENAME),	// jquery.qtip用のファイル
-																'url'		=>	self::JQUERY_QTIP_URL,
-																'version'	=>	self::JQUERY_QTIP_VER),
+																'url'		=> self::JQUERY_QTIP_URL,
+																'version'	=> self::JQUERY_QTIP_VER),
 					self::LIB_JQUERY_CALCULATION	=>	array(	'script' 	=> array(self::JQUERY_CALCULATION_FILENAME),	// jquery.calculation用のファイル
-																'url'		=>	self::JQUERY_CALCULATION_URL,
-																'version'	=>	self::JQUERY_CALCULATION_VER),
+																'url'		=> self::JQUERY_CALCULATION_URL,
+																'version'	=> self::JQUERY_CALCULATION_VER),
 					self::LIB_JQUERY_JQPLOT			=>	array(	'script' 	=> array(self::JQUERY_JQPLOT_FILENAME),	// jquery.jqplot用のファイル
-																'css'		=>	array(self::JQUERY_JQPLOT_CSS),
-																'dir'		=>	self::JQUERY_JQPLOT_DIR,
-																'url'		=>	self::JQUERY_JQPLOT_URL,
-																'version'	=>	self::JQUERY_JQPLOT_VER),
+																'css'		=> array(self::JQUERY_JQPLOT_CSS),
+																'dir'		=> self::JQUERY_JQPLOT_DIR,
+																'url'		=> self::JQUERY_JQPLOT_URL,
+																'version'	=> self::JQUERY_JQPLOT_VER),
 					self::LIB_JQUERY_YOUTUBEPLAYER	=>	array(	'script'	=> array(self::JQUERY_YOUTUBEPLAYER_FILENAME)),// jquery.youtubeplayer用のファイル
 					self::LIB_JQUERY_JSTREE			=>	array(	'script' 	=> array(self::JQUERY_JSTREE_FILENAME),	// jquery.jstree用のファイル
-																'url'		=>	self::JQUERY_JSTREE_URL,
-																'version'	=>	self::JQUERY_JSTREE_VER),
+																'url'		=> self::JQUERY_JSTREE_URL,
+																'version'	=> self::JQUERY_JSTREE_VER),
 					self::LIB_JQUERY_IFRAME			=>	array(	'script'	=> array(self::JQUERY_IFRAME_FILENAME),		// jquery.iframe-auto-height用のファイル
-																'url'		=>	self::JQUERY_IFRAME_URL,
-																'version'	=>	self::JQUERY_IFRAME_VER),
+																'url'		=> self::JQUERY_IFRAME_URL,
+																'version'	=> self::JQUERY_IFRAME_VER),
 					self::LIB_JQUERY_RATY			=>	array(	'script'	=> array(self::JQUERY_RATY_FILENAME),		// jquery.raty用のファイル
-																'url'		=>	self::JQUERY_RATY_URL,
-																'version'	=>	self::JQUERY_RATY_VER),
+																'url'		=> self::JQUERY_RATY_URL,
+																'version'	=> self::JQUERY_RATY_VER),
 					self::LIB_JQUERY_MOUSEWHEEL		=>	array(	'script'	=> array(self::JQUERY_MOUSEWHEEL_FILENAME),		// jquery.mousewheel用のファイル
-																'url'		=>	self::JQUERY_MOUSEWHEEL_URL,
-																'version'	=>	self::JQUERY_MOUSEWHEEL_VER),
+																'url'		=> self::JQUERY_MOUSEWHEEL_URL,
+																'version'	=> self::JQUERY_MOUSEWHEEL_VER),
 					self::LIB_JQUERY_CLOUDCAROUSEL	=>	array(	'script'	=> array(self::JQUERY_CLOUDCAROUSEL_FILENAME),		// jquery.cloudcarousel用のファイル
-																'url'		=>	self::JQUERY_CLOUDCAROUSEL_URL,
-																'version'	=>	self::JQUERY_CLOUDCAROUSEL_VER),
+																'url'		=> self::JQUERY_CLOUDCAROUSEL_URL,
+																'version'	=> self::JQUERY_CLOUDCAROUSEL_VER),
+					self::LIB_JQUERY_SCROLLTO		=>	array(	'script' 	=> array(self::JQUERY_SCROLLTO_FILENAME),	// jquery.scrollto用のファイル
+																'url'		=> self::JQUERY_SCROLLTO_URL,
+																'version'	=> self::JQUERY_SCROLLTO_VER),
 /*					self::LIB_JQUERY_JQEASYPANEL	=>	array(	'script' 	=> array(self::JQUERY_JQEASYPANEL_FILENAME),	// jquery.jqEasyPanel用のファイル
-																'css'		=>	array(self::JQUERY_JQEASYPANEL_CSS),
-																'url'		=>	self::JQUERY_JQEASYPANEL_URL,
-																'version'	=>	self::JQUERY_JQEASYPANEL_VER)*/
+																'css'		=> array(self::JQUERY_JQEASYPANEL_CSS),
+																'url'		=> self::JQUERY_JQEASYPANEL_URL,
+																'version'	=> self::JQUERY_JQEASYPANEL_VER)*/
 					// その他ライブラリ
-					self::LIB_CODEMIRROR_JAVASCRIPT		=>	array(	'script' 	=>	array(self::CODEMIRROR_FILENAME, self::CODEMIRROR_JAVASCRIPT_FILENAME),	// CodeMirror用のファイル
-																	'css'		=>	array(self::CODEMIRROR_CSS),
-																	'url'		=>	self::CODEMIRROR_URL,
-																	'version'	=>	self::CODEMIRROR_VER)
+					self::LIB_CODEMIRROR_JAVASCRIPT		=>	array(	'script' 	=> array(self::CODEMIRROR_FILENAME, self::CODEMIRROR_JAVASCRIPT_FILENAME),	// CodeMirror用のファイル
+																	'css'		=> array(self::CODEMIRROR_CSS),
+																	'url'		=> self::CODEMIRROR_URL,
+																	'version'	=> self::CODEMIRROR_VER)
 																);
 																
 		// WYSIWYGエディターに合わせてライブラリを設定
@@ -484,7 +493,8 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.7/jquery.jqplot.min.css';
 	 */
 	static function getScript($libId)
 	{
-		$scripts = self::getLib()[$libId]['script'];
+		$lib = self::getLib();
+		$scripts = $lib[$libId]['script'];
 		if (is_array($scripts) && count($scripts) == 1) $scripts = $scripts[0];
 		return $scripts;
 	}
