@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: mailManager.php 3076 2010-04-28 01:53:59Z fishbone $
+ * @version    SVN: $Id: mailManager.php 5361 2012-11-05 21:46:56Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -54,6 +54,10 @@ class MailManager extends Core
 	 */
 	public function sendFormMail($type, $widgetId, $toAddress, $fromAddress, $replytoAddress, $subject, $formId, $params, $ccAddress = '', $bccAddress = '', $mailForm = '')
 	{
+		global $gEnvManager;
+		
+		$langId = $gEnvManager->getCurrentLanguage();
+		
 		// 送信元、送信先のチェック
 		if (empty($toAddress) || empty($fromAddress)){
 			$this->gOpeLog->writeError(__METHOD__, 'メールアドレスが設定されていません。(送信先=' . $toAddress . ', 送信元=' . $fromAddress . ')', 1100);
@@ -74,7 +78,7 @@ class MailManager extends Core
 			$destSubject = $subject;
 			$destContent = $mailForm;
 		} else {
-			if (!$this->db->getMailForm($formId, $row)){
+			if (!$this->db->getMailForm($formId, $langId, $row)){
 				$this->gOpeLog->writeError(__METHOD__, 'メールフォームが見つかりません。(id=' . $formId . ')', 1100);
 				return false;
 			}
@@ -145,6 +149,33 @@ class MailManager extends Core
 		}
 		return $ret;
 	}
+	/**
+	 * メールフォームを取得
+	 *
+	 * @param string $id		フォームID
+	 * @param  string $langId	言語ID
+	 * @param  array  $row		取得レコード
+	 * @return bool				true=正常取得、false=取得できず
+	 */
+	function getMailForm($id, $langId, &$row)
+	{
+		$ret = $this->db->getMailForm($id, $langId, $row);
+		return $ret;
+	}
+	/**
+	 * メールフォーマットを更新
+	 *
+	 * @param string $id			フォームID
+	 * @param string $langId		言語ID
+	 * @param string $content		メール本文
+	 * @param string $subject		メール件名
+	 * @return bool 				true=正常、false=異常
+	 */
+	function updateMailForm($id, $langId, $content, $subject = null)
+	{
+		$ret = $this->db->updateMailForm($id, $langId, $content, $subject);
+		return $ret;
+	}
 	/**
 	 * メールアドレスに不正な文字列が入っていないかチェック
 	 *
