@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_commentBaseWidgetContainer.php 6042 2013-05-27 10:57:31Z fishbone $
+ * @version    SVN: $Id: admin_commentBaseWidgetContainer.php 6097 2013-06-12 12:05:49Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -22,8 +22,14 @@ class admin_commentBaseWidgetContainer extends BaseAdminWidgetContainer
 	protected static $_mainDb;			// DB接続オブジェクト
 	protected static $_configArray;		// ブログ定義値
 	protected static $_task;			// 現在の画面
+	protected $_openBy;				// ウィンドウオープンタイプ
+	protected $_baseUrl;			// 管理画面のベースURL
+	protected $_langId;			// 現在の言語
+	protected $_userId;			// 現在のユーザ
+	protected $_contentType;		// コンテンツタイプ
 	const DEFAULT_COMMENT_LENGTH	= 300;				// デフォルトのコメント最大文字数
 	const DEFAULT_CATEGORY_COUNT	= 2;				// デフォルトのカテゴリ数
+	const REQUEST_PARAM_CONTENT_TYPE = 'content_type';
 	
 	// カレンダー用スクリプト
 	const CALENDAR_SCRIPT_FILE = '/jscalendar-1.0/calendar.js';		// カレンダースクリプトファイル
@@ -50,8 +56,32 @@ class admin_commentBaseWidgetContainer extends BaseAdminWidgetContainer
 		// DBオブジェクト作成
 		if (!isset(self::$_mainDb)) self::$_mainDb = new commentDb();
 		
-		// ブログ定義を読み込む
-		//if (!isset(self::$_configArray)) self::$_configArray = commentCommonDef::loadConfig(self::$_mainDb);
+		$this->_langId = $this->gEnv->getCurrentLanguage();			// 現在の言語
+		$this->_userId = $this->gEnv->getCurrentUserId();		// 現在のユーザ
+	}
+	/**
+	 * テンプレートに前処理
+	 *
+	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
+	 * @return								なし
+	 */
+	function _preAssign($request, &$param)
+	{
+		$this->_openBy = $request->trimValueOf(M3_REQUEST_PARAM_OPEN_BY);		// ウィンドウオープンタイプ
+		if (!empty($this->_openBy)) $this->addOptionUrlParam(M3_REQUEST_PARAM_OPEN_BY, $this->_openBy);
+		
+		$this->_contentType = $request->trimValueOf(self::REQUEST_PARAM_CONTENT_TYPE);		// コンテンツタイプ
+		$value = $request->trimValueOf('item_content_type');		// 選択中のコンテンツタイプ
+		if (!empty($value)) $this->_contentType = $value;			// 画面からのPOST値で上書き
+		if (empty($this->_contentType)) $this->_contentType = $this->getDefaultContentType();		// コンテンツタイプが取得できないときはデフォルトを取得
+		
+		if (!empty($this->_contentType)) $this->addOptionUrlParam(self::REQUEST_PARAM_CONTENT_TYPE, $this->_contentType);		// コンテンツタイプをURLに追加
+		
+		// 管理画面ペースURL取得
+		$this->_baseUrl = $this->getAdminUrlWithOptionParam(true);		// ページ定義パラメータ付加
 	}
 	/**
 	 * テンプレートにデータ埋め込む
@@ -64,9 +94,9 @@ class admin_commentBaseWidgetContainer extends BaseAdminWidgetContainer
 	 */
 	function _postAssign($request, &$param)
 	{
-		$openBy = $request->trimValueOf(M3_REQUEST_PARAM_OPEN_BY);		// ウィンドウオープンタイプ
-		if (!empty($openBy)) $this->addOptionUrlParam(M3_REQUEST_PARAM_OPEN_BY, $openBy);
-		if ($openBy == 'simple') return;			// シンプルウィンドウのときはメニューを表示しない
+//		$openBy = $request->trimValueOf(M3_REQUEST_PARAM_OPEN_BY);		// ウィンドウオープンタイプ
+//		if (!empty($openBy)) $this->addOptionUrlParam(M3_REQUEST_PARAM_OPEN_BY, $openBy);
+		if ($this->_openBy == 'simple') return;			// シンプルウィンドウのときはメニューを表示しない
 		
 		// 表示画面を決定
 	//	$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);
@@ -91,17 +121,17 @@ class admin_commentBaseWidgetContainer extends BaseAdminWidgetContainer
 		$menuText .= '<ul>' . M3_NL;
 		
 		$current = '';
-		$baseUrl = $this->getAdminUrlWithOptionParam();
+//		$baseUrl = $this->getAdminUrlWithOptionParam();
 		
 		// コメント一覧
 		$current = '';
-		$link = $baseUrl . '&task=' . self::TASK_COMMENT;
+		$link = $this->_baseUrl . '&task=' . self::TASK_COMMENT;
 		if ($task == self::TASK_COMMENT || $task == self::TASK_COMMENT_DETAIL) $current = 'id="current"';
 		$menuText .= '<li ' . $current . '><a href="'. $this->getUrl($link) .'"><span>コメント一覧</span></a></li>' . M3_NL;
 		
 		// 基本設定
 		$current = '';
-		$link = $baseUrl . '&task=' . self::TASK_CONFIG;
+		$link = $this->_baseUrl . '&task=' . self::TASK_CONFIG;
 		if ($task == self::TASK_CONFIG || $task == self::TASK_CONFIG_LIST || $task == self::TASK_CONFIG_DETAIL) $current = 'id="current"';
 		$menuText .= '<li ' . $current . '><a href="'. $this->getUrl($link) .'"><span>基本設定</span></a></li>' . M3_NL;
 		
@@ -114,5 +144,26 @@ class admin_commentBaseWidgetContainer extends BaseAdminWidgetContainer
 		$outputText .= '<table width="90%"><tr><td>' . $linkList . $menuText . '</td></tr></table>' . M3_NL;
 		$this->tmpl->addVar("_widget", "menu_items", $outputText);
 	}
+	/**
+	 * デフォルトのコンテンツタイプを取得
+	 *
+	 * @return string						コンテンツタイプ
+	 */
+	function getDefaultContentType()
+	{
+		$contentType = '';
+		if (!empty($this->_defSerial)){	// ページ作成からの遷移の場合
+			$contentType = '';
+			$ret = $this->_db->getPageDefBySerial($this->_defSerial, $row);
+			if ($ret){
+				$pageId = $row['pd_id'];
+				$pageSubId = $row['pd_sub_id'];
+				$pageInfo = $this->gPage->getPageInfo($pageId, $pageSubId);
+				$contentType = $pageInfo['pn_content_type'];
+			}
+			if (empty($contentType)) $contentType = M3_VIEW_TYPE_CONTENT;				// 汎用コンテンツ
+		}
+		return $contentType;
+	}
 }
 ?>
