@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_commentCommentWidgetContainer.php 6066 2013-06-03 00:28:13Z fishbone $
+ * @version    SVN: $Id: admin_commentCommentWidgetContainer.php 6101 2013-06-13 05:30:29Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getWidgetContainerPath('comment') . '/admin_commentBaseWidgetContainer.php');
@@ -22,10 +22,15 @@ class admin_commentCommentWidgetContainer extends admin_commentBaseWidgetContain
 	private $serialArray = array();		// 表示されている項目シリアル番号
 	private $contentType;		// 選択中のコンテンツタイプ
 	private $contentTypeArray;		// コンテンツ選択メニュー用
+	private $permitHtml;		// HTMLあり
+	private $status;			// コメント状態(0=未設定、1=非公開、2=公開)
+	private $statusTypeArray;	// コメント状態メニュー作成用
+	
 	const DEFAULT_LIST_COUNT = 20;			// 最大リスト表示数
 	const COMMENT_SIZE = 40;			// コメント内容の最大文字列長
 	const SEARCH_ICON_FILE = '/images/system/search16.png';		// 検索用アイコン
 	const PREVIEW_ICON_FILE = '/images/system/preview.png';		// プレビュー用アイコン
+	const UNTITLED_CONTENT = 'タイトル未設定';
 	
 	/**
 	 * コンストラクタ
@@ -36,8 +41,11 @@ class admin_commentCommentWidgetContainer extends admin_commentBaseWidgetContain
 		parent::__construct();
 		
 		// 初期設定
-		$this->contentTypeArray = array_merge(array(array('name' => '[すべて]', 'value' => '_all')), $this->gPage->getMainContentType());// コンテンツタイプ取得
+		$this->contentTypeArray = array_merge(array(array('name' => '[すべて]', 'value' => '')), $this->gPage->getMainContentType());// コンテンツタイプ取得
 		$this->langId = $this->gEnv->getDefaultLanguage();
+		$this->statusTypeArray = array(	array(	'name' => '未承認',	'value' => '0'),
+										array(	'name' => '非公開',	'value' => '1'),
+										array(	'name' => '公開',	'value' => '2'));
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -123,8 +131,8 @@ class admin_commentCommentWidgetContainer extends admin_commentBaseWidgetContain
 		
 		// 入力値取得
 		$act = $request->trimValueOf('act');
-		$this->contentType = $request->trimValueOf('content_type');		// 選択中のコンテンツタイプ	
-		if (empty($this->contentType)) $this->contentType = $request->trimValueOf('item_content_type');		// 選択中のコンテンツタイプ
+//		$this->contentType = $request->trimValueOf('content_type');		// 選択中のコンテンツタイプ	
+//		if (empty($this->contentType)) $this->contentType = $request->trimValueOf('item_content_type');		// 選択中のコンテンツタイプ
 
 		// ##### 検索条件 #####
 		$pageNo = $request->trimValueOf('page');				// ページ番号
@@ -163,7 +171,7 @@ class admin_commentCommentWidgetContainer extends admin_commentBaseWidgetContain
 			$pageNo = 1;		// ページ番号初期化
 		} else if ($act == 'selcontenttype'){		// コンテンツタイプ変更のとき
 		} else {
-			$this->contentType = $this->getDefaultContentType();			// コンテンツタイプ
+//			$this->contentType = $this->getDefaultContentType();			// コンテンツタイプ
 		}
 		
 		// コンテンツ選択メニュー作成
@@ -174,7 +182,7 @@ class admin_commentCommentWidgetContainer extends admin_commentBaseWidgetContain
 		$parsedKeywords = $this->gInstance->getTextConvManager()->parseSearchKeyword($keyword);
 		
 		// 総数を取得
-		$totalCount = self::$_mainDb->getCommentItemCount($this->contentType, $this->langId, $search_startDt, $endDt, $parsedKeywords);
+		$totalCount = self::$_mainDb->getCommentItemCount($this->_contentType, $this->langId, $search_startDt, $endDt, $parsedKeywords);
 
 		// 表示するページ番号の修正
 		$pageCount = (int)(($totalCount -1) / $maxListCount) + 1;		// 総ページ数
@@ -196,7 +204,7 @@ class admin_commentCommentWidgetContainer extends admin_commentBaseWidgetContain
 		}
 		
 		// コメントリストを取得
-		self::$_mainDb->searchCommentItems($this->contentType, $this->langId, $maxListCount, $pageNo, $search_startDt, $endDt, $parsedKeywords, array($this, 'itemListLoop'));
+		self::$_mainDb->searchCommentItems($this->_contentType, $this->langId, $maxListCount, $pageNo, $search_startDt, $endDt, $parsedKeywords, array($this, 'itemListLoop'));
 		if (count($this->serialArray) <= 0) $this->tmpl->setAttribute('itemlist', 'visibility', 'hidden');// コメントがないときは、一覧を表示しない
 
 		// ボタン作成
@@ -218,6 +226,8 @@ class admin_commentCommentWidgetContainer extends admin_commentBaseWidgetContain
 		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
 		$this->tmpl->addVar("_widget", "page", $pageNo);	// ページ番号
 		$this->tmpl->addVar("_widget", "list_count", $maxListCount);	// 一覧表示項目数
+//		$this->tmpl->addVar('_widget', 'config_admin_url', $this->getUrl($this->getConfigAdminUrl()));// コメント管理画面URL
+		$this->tmpl->addVar('_widget', 'config_admin_url', $this->getUrl($this->_baseUrl));
 	}
 	/**
 	 * 詳細画面作成
@@ -227,36 +237,35 @@ class admin_commentCommentWidgetContainer extends admin_commentBaseWidgetContain
 	 */
 	function createDetail($request)
 	{
-		// デフォルト値
-
 		$act = $request->trimValueOf('act');
 		$this->serialNo = $request->trimValueOf('serial');		// 選択項目のシリアル番号
 		if (empty($this->serialNo)) $this->serialNo = 0;
-		$name = $request->trimValueOf('item_name');
-		$html = $request->valueOf('item_html');
-		$url = $request->valueOf('item_url');
-		$email = $request->valueOf('item_email');
-		$reg_user = $request->valueOf('item_reg_user');
-		$status = $request->trimValueOf('item_status');		// エントリー状態(0=未設定、1=編集中、2=公開、3=非公開)
+//		$name = $request->trimValueOf('item_name');
+//		$html = $request->valueOf('item_html');
+//		$url = $request->valueOf('item_url');
+//		$email = $request->valueOf('item_email');
+//		$reg_user = $request->valueOf('item_reg_user');
+		$this->status = $request->trimValueOf('item_status');		// エントリー状態(0=未設定、1=編集中、2=公開、3=非公開)
+//		$this->contentType = $request->trimValueOf('content_type');		// 選択中のコンテンツタイプ
 
-		$dataReload = false;		// データの再ロード
+		// コメント定義取得
+		$ret = self::$_mainDb->getConfig($this->_contentType, ''/*全体の定義*/, $row);
+		if ($ret){
+			$this->permitHtml		= $row[commentCommonDef::FD_PERMIT_HTML];		// HTMLあり
+		} else {
+			$this->permitHtml = 0;		// HTMLあり
+		}
+		
+		$reloadData = false;		// データの再ロード
 		if ($act == 'update'){		// 項目更新の場合
 			// エラーなしの場合は、データを更新
 			if ($this->getMsgCount() == 0){
-				$ret = self::$_mainDb->updateCommentItem($this->serialNo, $name, $html, $url, $reg_user, $email);
-				
-				// 記事更新日を更新
-				if ($ret){
-					$ret = self::$_mainDb->getCommentBySerial($this->serialNo, $row);
-					if ($ret){
-						$langId = $row['be_language_id'];		// 言語ID
-						$ret = self::$_mainDb->updateEntryDt($entryId, $langId);
-					}
-				}
+				$fieldData = array('cm_status' => $this->status);
+				$ret = self::$_mainDb->updateCommentItem($this->serialNo, $fieldData);
 				
 				if ($ret){
 					$this->setGuidanceMsg('データを更新しました');
-					$dataReload = true;		// データの再ロード
+					$reloadData = true;		// データの再ロード
 				} else {
 					$this->setAppErrorMsg('データ更新に失敗しました');
 				}
@@ -276,55 +285,70 @@ class admin_commentCommentWidgetContainer extends admin_commentBaseWidgetContain
 			}
 		} else if ($act == 'deleteid'){		// ID項目削除の場合
 		} else {	// 初期画面表示のとき
-			$dataReload = true;		// データの再ロード
+			$reloadData = true;		// データの再ロード
 		}
 		
 		// 設定データを再取得
-		if ($dataReload){		// データの再ロード
-			$ret = self::$_mainDb->getCommentBySerial($this->serialNo, $row);
+		if ($reloadData){		// データの再ロード
+			$ret = self::$_mainDb->getCommentItem($this->serialNo, $row);
 			if ($ret){
-				$entryTitle = $row['be_name'];				// 記事タイトル
-				$name = $row['bo_name'];				// コメントタイトル
-				$html = $row['bo_html'];				// HTML
-				$email = $row['bo_email'];				// eメール
-				$url = $row['bo_url'];				// URL
-				$reg_user = $row['bo_user_name'];				// 投稿者
-				$reg_dt = $this->convertToDispDateTime($row['bo_regist_dt']);				// 投稿日時
+				$contentsId = $row['cm_contents_id'];				// 共通コンテンツID
+				$title = $row['cm_title'];				// コメントタイトル
+				$this->status = $row['cm_status'];			// コメント状態(0=未設定、1=非公開、2=公開)
+
+				if ($this->permitHtml){			// HTMLコメントの場合
+					$commentTag = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->currentPageRootUrl, $row['cm_message']);// アプリケーションルートを変換
+				} else {
+					$commentTag = $this->convertToPreviewText($this->convertToDispString($row['cm_message']));// 改行コードをbrタグに変換
+				}
+				$email = $row['cm_email'];				// Eメール
+				if (!empty($row['lu_email'])) $email = $row['lu_email'];
+				$url = $row['cm_url'];				// URL
+				$author = $row['cm_author'];				// 投稿者
+				if (!empty($row['author'])) $author = $row['author'];
+				$reg_dt = $row['cm_create_dt'];				// 投稿日時
 				$update_user = $row['update_user_name'];		// 更新者
-				$update_dt = $this->convertToDispDateTime($row['bo_update_dt']);		// 更新日時
+				$update_dt = $row['cm_update_dt'];		// 更新日時
+				
+				// コンテンツタイトル取得
+				$contentTitle = $this->getContentTitle($this->_contentType, $contentsId);
 			}
 		}
+		// コメント状態メニュー作成
+		$this->createStatusMenu();
 		
 		// 非表示項目を設定
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);	// シリアル番号
 
 		// 入力フィールドの設定、共通項目のデータ設定
-		if ($this->entryId == 0){		// 記事IDが0のときは、新規追加モードにする
+/*		if ($this->entryId == 0){		// 記事IDが0のときは、新規追加モードにする
 			$this->tmpl->addVar('_widget', 'id', '新規');
 			
 			$this->tmpl->setAttribute('add_button', 'visibility', 'visible');
 		} else {
 			$this->tmpl->addVar('_widget', 'id', $this->entryId);
-			
+			*/
 			if ($this->serialNo == 0){		// 未登録データのとき
 				// データ追加ボタン表示
 				$this->tmpl->setAttribute('add_button', 'visibility', 'visible');
 			} else {
 				// データ更新、削除ボタン表示
-				$this->tmpl->setAttribute('delete_button', 'visibility', 'visible');// デフォルト言語以外はデータ削除
+				$this->tmpl->setAttribute('delete_button', 'visibility', 'visible');
 				$this->tmpl->setAttribute('update_button', 'visibility', 'visible');
 			}
-		}
-		// ### 入力値を再設定 ###
-		$this->tmpl->addVar("_widget", "entry_title", $this->convertToDispString($entryTitle));		// 記事タイトル
-		$this->tmpl->addVar("_widget", "name", $this->convertToDispString($name));		// コメントタイトル
-		$this->tmpl->addVar("_widget", "html", $this->convertToDispString($html));		// HTML
+//		}
+		// 表示項目を埋め込む
+		$this->tmpl->addVar("_widget", "content_title", $this->convertToDispString($contentTitle));		// コンテンツタイトル
+		$this->tmpl->addVar("_widget", "title", $this->convertToDispString($title));		// コメントタイトル
+		$this->tmpl->addVar("_widget", "comment", $commentTag);		// コメント内容
 		$this->tmpl->addVar("_widget", "email", $this->convertToDispString($email));		// Eメール
 		$this->tmpl->addVar("_widget", "url", $this->convertToDispString($url));		// URL
-		$this->tmpl->addVar("_widget", "reg_user", $this->convertToDispString($reg_user));		// 投稿者
-		$this->tmpl->addVar("_widget", "entry_dt", $reg_dt);	// 投稿日時
+		$this->tmpl->addVar("_widget", "author", $this->convertToDispString($author));		// 投稿者
+		$this->tmpl->addVar("_widget", "date", $this->convertToDispDateTime($reg_dt));	// 投稿日時
 		$this->tmpl->addVar("_widget", "update_user", $this->convertToDispString($update_user));	// 更新者
-		$this->tmpl->addVar("_widget", "update_dt", $update_dt);	// 更新日時
+		$this->tmpl->addVar("_widget", "update_dt", $this->convertToDispDateTime($update_dt));	// 更新日時
+		//$this->tmpl->addVar('_widget', 'config_admin_url', $this->getUrl($this->getConfigAdminUrl()));// コメント管理画面URL
+		$this->tmpl->addVar('_widget', 'config_admin_url', $this->getUrl($this->_baseUrl));
 	}
 	/**
 	 * 取得したデータをテンプレートに設定する
@@ -339,41 +363,47 @@ class admin_commentCommentWidgetContainer extends admin_commentBaseWidgetContain
 		// シリアル番号
 		$serial = $fetchedRow['cm_serial'];
 		
-		// 記事ID
-		$entryId = $fetchedRow['be_id'];
+		// 共通コンテンツID
+		$contentsId = $fetchedRow['cm_contents_id'];
 		
 		// 公開状態
 		switch ($fetchedRow['cm_status']){
 			case 0:	$status = '<font color="red">未承認</font>';
 				break;
-			case 1:	$status = '<font color="green">公開</font>';
+			case 1:	$status = '<font color="orange">非公開</font>';
 				break;
-			case 2:	$status = '非公開';
+			case 2:	$status = '<font color="green">公開</font>';
 				break;
 		}
+		// コンテンツタイトル取得
+		$title = $this->getContentTitle($this->_contentType, $contentsId);
 		
+		$userName = $fetchedRow['lu_name'];
+		if (empty($userName)) $userName = $fetchedRow['cm_author'];
+			
 		// コメント内容
+		$comment = strip_tags($fetchedRow['cm_message']);		// タグを削除
 		if (function_exists('mb_strimwidth')){
-			$comment = mb_strimwidth($fetchedRow['cm_message'], 0, self::COMMENT_SIZE, '…');
+			$comment = mb_strimwidth($comment, 0, self::COMMENT_SIZE, '…');
 		} else {
-			$comment = substr($fetchedRow['cm_message'], 0, self::COMMENT_SIZE) . '...';
+			$comment = substr($comment, 0, self::COMMENT_SIZE) . '...';
 		}
 		// プレビュー用URL
-		$previewUrl = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_CONTENT_ID . '=' . $contentId;
-//		$previewUrl .= '&' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_PREVIEW;// プレビュー用URL
+//		$previewUrl = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_CONTENT_ID . '=' . $contentId;
+		$previewUrl = commentCommonDef::createCommentUrl($this->_contentType, $contentsId, $fetchedRow['cm_no']);
 		$previewImg = $this->getUrl($this->gEnv->getRootUrl() . self::PREVIEW_ICON_FILE);
 		$previewStr = 'プレビュー';
 		
 		$row = array(
 			'index' => $index,		// 項目番号
-			'no' => $index + 1,													// 行番号
 			'serial' => $serial,			// シリアル番号
-			'entry_name' => $this->convertToDispString($fetchedRow['be_name']),		// 記事タイトル
+			'content_title' => $this->convertToDispString($title),		// コンテンツタイトル
+			'no'	=> $this->convertToDispString($fetchedRow['cm_no']),		// コメント番号
 			'name' => $this->convertToDispString($fetchedRow['cm_title']),		// コメントタイトル
 			'content' => $this->convertToDispString($comment),		// コメント内容
 			'status' => $status,													// 公開状況
-			'reg_user' => $this->convertToDispString($fetchedRow['cm_author']),	// 投稿者
-			'reg_date' => $this->convertToDispDateTime($fetchedRow['cm_regist_dt']),	// 投稿日時
+			'author' => $this->convertToDispString($userName),	// 投稿者
+			'date' => $this->convertToDispDateTime($fetchedRow['cm_create_dt']),	// 投稿日時
 			'preview_url' => $previewUrl,											// プレビュー用のURL
 			'preview_img' => $previewImg,											// プレビュー用の画像
 			'preview_str' => $previewStr									// プレビュー文字列
@@ -399,29 +429,78 @@ class admin_commentCommentWidgetContainer extends admin_commentBaseWidgetContain
 			$row = array(
 				'name' => $name,		// 名前
 				'value' => $value,		// 値
-				'selected' => $this->convertToSelectedString($value, $this->contentType)	// 選択中の項目かどうか
+				'selected' => $this->convertToSelectedString($value, $this->_contentType)	// 選択中の項目かどうか
 			);
 			$this->tmpl->addVars('content_type_list', $row);
 			$this->tmpl->parseTemplate('content_type_list', 'a');
 		}
 	}
 	/**
-	 * デフォルトのコンテンツタイプを取得
+	 * コンテンツタイトル取得
 	 *
-	 * @return string						コンテンツタイプ
+	 * @param string $contentType		コンテンツタイプ
+	 * @param string $contentsId		共通コンテンツID
+	 * @param string					タイトル
 	 */
-	function getDefaultContentType()
+	function getContentTitle($contentType, $contentsId)
 	{
-		$contentType = '';
-		$ret = $this->_db->getPageDefBySerial($this->_defSerial, $row);
-		if ($ret){
-			$pageId = $row['pd_id'];
-			$pageSubId = $row['pd_sub_id'];
-			$pageInfo = $this->gPage->getPageInfo($pageId, $pageSubId);
-			$contentType = $pageInfo['pn_content_type'];
+		$contentName = self::UNTITLED_CONTENT;
+		
+		switch ($contentType){
+			case M3_VIEW_TYPE_CONTENT:				// 汎用コンテンツ
+				$ret = self::$_mainDb->getContentById(''/*PC用コンテンツ*/, $this->_langId, $contentsId, $row);
+				if ($ret) $contentName = $row['cn_name'];
+				break;
+			case M3_VIEW_TYPE_PRODUCT:				// 商品情報(Eコマース)
+				$ret = self::$_mainDb->getProductById($contentsId, $this->_langId, $row);
+				if ($ret) $contentName = $row['pt_name'];
+				break;
+			case M3_VIEW_TYPE_BBS:					// BBS
+				// 未使用
+				break;
+			case M3_VIEW_TYPE_BLOG:				// ブログ
+				$ret = self::$_mainDb->getEntryById($contentsId, $this->_langId, $row);
+				if ($ret) $contentName = $row['be_name'];
+				break;
+			case M3_VIEW_TYPE_WIKI:				// wiki
+				$contentName = $contentsId;
+				break;
+			case M3_VIEW_TYPE_USER:				// ユーザ作成コンテンツ
+				$ret = self::$_mainDb->getRoomById($contentsId, $this->_langId, $row);
+				if ($ret) $contentName = $row['ur_name'];
+				break;
+			case M3_VIEW_TYPE_EVENT:				// イベント情報
+				$ret = self::$_mainDb->getEventById($contentsId, $this->_langId, $row);
+				if ($ret) $contentName = $row['ee_name'];
+				break;
+			case M3_VIEW_TYPE_PHOTO:				// フォトギャラリー
+				$ret = self::$_mainDb->getPhotoById($contentsId, $this->_langId, $row);
+				if ($ret) $contentName = $row['ht_name'];
+				break;
+		}
+		return $contentName;
+	}
+	/**
+	 * コメント状態選択タイプメニュー作成
+	 *
+	 * @return なし
+	 */
+	function createStatusMenu()
+	{
+		for ($i = 0; $i < count($this->statusTypeArray); $i++){
+			$value = $this->statusTypeArray[$i]['value'];
+			$name = $this->statusTypeArray[$i]['name'];
+			$selected = '';
+			if ($this->status == $value) $selected = 'selected';
+			
+			$row = array(
+				'value'    => $value,			// タイプ値
+				'name'     => $this->convertToDispString($name),			// タイプ名
+				'selected' => $selected			// 選択中かどうか
+			);
+			$this->tmpl->addVars('status_list', $row);
+			$this->tmpl->parseTemplate('status_list', 'a');
 		}
-		if (empty($contentType)) $contentType = M3_VIEW_TYPE_CONTENT;				// 汎用コンテンツ
-		return $contentType;
 	}
 }
 ?>
