@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_commentConfigWidgetContainer.php 6066 2013-06-03 00:28:13Z fishbone $
+ * @version    SVN: $Id: admin_commentConfigWidgetContainer.php 6101 2013-06-13 05:30:29Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getWidgetContainerPath('comment') . '/admin_commentBaseWidgetContainer.php');
@@ -42,7 +42,6 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 		// 初期設定
 		$this->contentTypeArray = $this->gPage->getMainContentType();// コンテンツタイプ取得
 		$this->langId = $this->gEnv->getDefaultLanguage();
-		$this->configAdminUrl = $this->getConfigAdminUrl();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -95,8 +94,8 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 	{
 		// 入力値取得
 		$act = $request->trimValueOf('act');
-		$this->contentType = $request->trimValueOf('content_type');		// 選択中のコンテンツタイプ
-		if (empty($this->contentType)) $this->contentType = $request->trimValueOf('item_content_type');		// 選択中のコンテンツタイプ
+//		$this->contentType = $request->trimValueOf('content_type');		// 選択中のコンテンツタイプ
+//		if (empty($this->contentType)) $this->contentType = $request->trimValueOf('item_content_type');		// 選択中のコンテンツタイプ
 		$viewType = $request->trimValueOf('item_view_type');				// コメントタイプ
 		$viewCount = $request->trimValueOf('item_view_count');			// 表示項目数
 		$viewDirection = $request->trimValueOf('item_view_direction');				// 表示順
@@ -107,9 +106,11 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 		$userLimited = ($request->trimValueOf('item_user_limited') == 'on') ? 1 : 0;		// ユーザ制限あり
 		$permitHtml = ($request->trimValueOf('item_permit_html') == 'on') ? 1 : 0;		// HTMLあり
 		$permitImage = ($request->trimValueOf('item_permit_image') == 'on') ? 1 : 0;		// 画像あり
+		$autolink = ($request->trimValueOf('item_autolink') == 'on') ? 1 : 0;		// 自動リンク作成
 		$maxLength = $request->trimValueOf('item_max_length');			// 文字数
 		$useTitle = ($request->trimValueOf('item_use_title') == 'on') ? 1 : 0;		// タイトルあり
 		$useAuthor = ($request->trimValueOf('item_use_author') == 'on') ? 1 : 0;		// 投稿者名あり
+		$useDate = ($request->trimValueOf('item_use_date') == 'on') ? 1 : 0;		// 投稿日時あり
 		$useEmail = ($request->trimValueOf('item_use_email') == 'on') ? 1 : 0;		// Eメールあり
 		$useUrl = ($request->trimValueOf('item_use_url') == 'on') ? 1 : 0;		// URLあり
 		$useAvatar = ($request->trimValueOf('item_use_avatar') == 'on') ? 1 : 0;		// アバターあり
@@ -117,7 +118,7 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 		$reloadData = false;		// データの再読み込み
 		if ($act == 'update'){		// 設定更新のとき
 			// 入力値のエラーチェック
-			$this->checkInput($this->contentType, 'コンテンツタイプ');
+			$this->checkInput($this->_contentType, 'コンテンツタイプ');
 			$this->checkNumeric($viewCount, '表示項目数');
 			$this->checkNumeric($maxLength, '文字数');
 			
@@ -136,13 +137,15 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 			    $fieldValues[commentCommonDef::FD_USER_LIMITED]		= intval($userLimited);		// 投稿ユーザを制限
 			    $fieldValues[commentCommonDef::FD_PERMIT_HTML]		= intval($permitHtml);		// HTMLメッセージ
 			    $fieldValues[commentCommonDef::FD_PERMIT_IMAGE]		= intval($permitImage);		// 画像あり
+				$fieldValues[commentCommonDef::FD_AUTOLINK]			= intval($autolink);		// 自動リンク作成
 			    $fieldValues[commentCommonDef::FD_USE_TITLE]		= intval($useTitle);		// タイトルあり
 			    $fieldValues[commentCommonDef::FD_USE_AUTHOR]		= intval($useAuthor);		// 投稿者名あり
+				$fieldValues[commentCommonDef::FD_USE_DATE]			= intval($useDate);		// 投稿日時あり
 			    $fieldValues[commentCommonDef::FD_USE_EMAIL]		= intval($useEmail);		// Eメールあり
 			    $fieldValues[commentCommonDef::FD_USE_URL]			= intval($useUrl);		// URLあり
 			    $fieldValues[commentCommonDef::FD_USE_AVATAR]		= intval($useAvatar);		// アバターあり
 	
-				$ret = self::$_mainDb->updateConfig($this->contentType, ''/*全体の定義*/, $fieldValues);
+				$ret = self::$_mainDb->updateConfig($this->_contentType, ''/*全体の定義*/, $fieldValues);
 				if ($ret){
 					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
 				} else {
@@ -153,13 +156,13 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 		} else if ($act == 'selcontenttype'){		// コンテンツタイプ変更のとき
 			$reloadData = true;		// データの再読み込み
 		} else {		// 初期表示の場合
-			if (empty($this->contentType)) $this->contentType = $this->getDefaultContentType();			// コンテンツタイプ
+//			if (empty($this->contentType)) $this->contentType = $this->getDefaultContentType();			// コンテンツタイプ
 			
 			$reloadData = true;		// データの再読み込み
 		}
 		if ($reloadData){		// データの再読み込み
 			// コメント定義取得
-			$ret = self::$_mainDb->getConfig($this->contentType, ''/*全体の定義*/, $row);
+			$ret = self::$_mainDb->getConfig($this->_contentType, ''/*全体の定義*/, $row);
 			if ($ret){
 				$viewType				= $row[commentCommonDef::FD_VIEW_TYPE];				// コメントタイプ(フラット)
 				$viewCount				= $row[commentCommonDef::FD_MAX_COUNT];			// 表示項目数
@@ -171,9 +174,11 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 				$userLimited			= $row[commentCommonDef::FD_USER_LIMITED];		// ユーザ制限あり
 				$permitHtml				= $row[commentCommonDef::FD_PERMIT_HTML];		// HTMLあり
 				$permitImage			= $row[commentCommonDef::FD_PERMIT_IMAGE];		// 画像あり
+				$autolink				= $row[commentCommonDef::FD_AUTOLINK];		// 自動リンク作成
 				$maxLength				= $row[commentCommonDef::FD_MAX_LENGTH];			// 文字数
 				$useTitle				= $row[commentCommonDef::FD_USE_TITLE];		// タイトルあり
 				$useAuthor				= $row[commentCommonDef::FD_USE_AUTHOR];		// 投稿者名あり
+				$useDate				= $row[commentCommonDef::FD_USE_DATE];		// 投稿日時あり
 				$useEmail				= $row[commentCommonDef::FD_USE_EMAIL];		// Eメールあり
 				$useUrl					= $row[commentCommonDef::FD_USE_URL];		// URLあり
 				$useAvatar				= $row[commentCommonDef::FD_USE_AVATAR];		// アバターあり
@@ -188,9 +193,11 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 				$userLimited = 0;		// ユーザ制限あり
 				$permitHtml = 0;		// HTMLあり
 				$permitImage = 0;		// 画像あり
+				$autolink = 1;		// 自動リンク作成
 				$maxLength = commentCommonDef::DF_MAX_LENGTH;			// 文字数
 				$useTitle = 0;		// タイトルあり
 				$useAuthor = 1;		// 投稿者名あり
+				$useDate = 1;		// 投稿日時あり
 				$useEmail = 0;		// Eメールあり
 				$useUrl = 0;		// URLあり
 				$useAvatar = 1;		// アバターあり
@@ -215,14 +222,16 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 		$this->tmpl->addVar('_widget', 'user_limited_checked', $this->convertToCheckedString($userLimited));	// ユーザ制限あり
 		$this->tmpl->addVar('_widget', 'permit_html_checked', $this->convertToCheckedString($permitHtml));		// HTMLあり
 		$this->tmpl->addVar('_widget', 'permit_image_checked', $this->convertToCheckedString($permitImage));		// 画像あり
+		$this->tmpl->addVar('_widget', 'autolink_checked', $this->convertToCheckedString($autolink));		// 自動リンク作成
 		$this->tmpl->addVar('_widget', 'use_title_checked', $this->convertToCheckedString($useTitle));		// タイトルあり
 		$this->tmpl->addVar('_widget', 'use_author_checked', $this->convertToCheckedString($useAuthor));		// 投稿者名あり
+		$this->tmpl->addVar('_widget', 'use_date_checked', $this->convertToCheckedString($useDate));		// 投稿日時あり
 		$this->tmpl->addVar('_widget', 'use_email_checked', $this->convertToCheckedString($useEmail));		// Eメールあり
 		$this->tmpl->addVar('_widget', 'use_url_checked', $this->convertToCheckedString($useUrl));		// URLあり
 		$this->tmpl->addVar('_widget', 'use_avatar_checked', $this->convertToCheckedString($useAvatar));		// アバターあり
 		
 		$this->tmpl->addVar('_widget', 'message', $message);		// メッセージ
-		$this->tmpl->addVar('_widget', 'config_admin_url', $this->getUrl($this->configAdminUrl));// コンテンツ一覧画面URL
+		$this->tmpl->addVar('_widget', 'config_admin_url', $this->getUrl($this->_baseUrl));
 	}
 	/**
 	 * 詳細画面作成
@@ -236,7 +245,7 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 		$act = $request->trimValueOf('act');
 		$pageNo = $request->trimValueOf('page');				// ページ番号
 		if (empty($pageNo)) $pageNo = 1;
-		$this->contentType = $request->trimValueOf('content_type');		// 選択中のコンテンツタイプ
+//		$this->contentType = $request->trimValueOf('content_type');		// 選択中のコンテンツタイプ
 		$contentsId = $request->trimValueOf('contentsid');		// コンテンツID
 		
 		$commentVisible = ($request->trimValueOf('item_comment_visible') == 'on') ? 1 : 0;		// コメントを表示する
@@ -249,7 +258,7 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 			    $fieldValues['cf_visible']			= intval($commentVisible);		// 表示可否(個別設定可)
 			    $fieldValues['cf_accept_post']		= intval($commentAccept);		// コメントの受付(個別設定可)
 	
-				$ret = self::$_mainDb->updateConfig($this->contentType, $contentsId, $fieldValues);
+				$ret = self::$_mainDb->updateConfig($this->_contentType, $contentsId, $fieldValues);
 				if ($ret){
 					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
 				} else {
@@ -262,12 +271,12 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 		}
 		if ($reloadData){		// データの再読み込み
 			// コメント定義取得
-			$ret = self::$_mainDb->getConfig($this->contentType, $contentsId, $row);
+			$ret = self::$_mainDb->getConfig($this->_contentType, $contentsId, $row);
 			if ($ret){
 				$commentVisible			= $row[commentCommonDef::FD_VISIBLE];		// コメントを表示する
 				$commentAccept			= $row[commentCommonDef::FD_ACCEPT_POST];		// コメントを受け付ける
 			} else {		// コンテンツ個別設定がない場合はデフォルトを取得
-				$ret = self::$_mainDb->getConfig($this->contentType, ''/*全体の定義*/, $row);
+				$ret = self::$_mainDb->getConfig($this->_contentType, ''/*全体の定義*/, $row);
 				if ($ret){
 					$commentVisible	= $row[commentCommonDef::FD_VISIBLE_D];		// コメントを表示する(個別デフォルト)
 					$commentAccept	= $row[commentCommonDef::FD_ACCEPT_POST_D];		// コメントを受け付ける(個別デフォルト)
@@ -283,12 +292,12 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 		
 		$contentTypeName = '';
 		for ($i = 0; $i < count($this->contentTypeArray); $i++){
-			if ($this->contentTypeArray[$i]['value'] == $this->contentType) $contentTypeName = $this->contentTypeArray[$i]['name'];
+			if ($this->contentTypeArray[$i]['value'] == $this->_contentType) $contentTypeName = $this->contentTypeArray[$i]['name'];
 		}
 		
 		// パラメータ引継ぎ
 		$this->tmpl->addVar("_widget", "page_no", $this->convertToDispString($pageNo));		// ページ番号
-		$this->tmpl->addVar("_widget", "content_type", $this->convertToDispString($this->contentType));		// コンテンツタイプ
+		$this->tmpl->addVar("_widget", "content_type", $this->convertToDispString($this->_contentType));		// コンテンツタイプ
 		
 		// その他
 		$this->tmpl->addVar('_widget', 'comment_visible_checked', $this->convertToCheckedString($commentVisible));		// コメントを表示する
@@ -297,7 +306,7 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 		$this->tmpl->addVar("_widget", "name", $this->convertToDispString($contentName));
 		$this->tmpl->addVar("_widget", "content_type_name", $this->convertToDispString($contentTypeName));		// コンテンツタイプ名
 		$this->tmpl->setAttribute('update_button', 'visibility', 'visible');// 更新ボタン表示
-		$this->tmpl->addVar('_widget', 'config_admin_url', $this->getUrl($this->configAdminUrl));// コンテンツ一覧画面URL
+		$this->tmpl->addVar('_widget', 'config_admin_url', $this->getUrl($this->_baseUrl));
 	}
 	/**
 	 * 一覧画面作成
@@ -314,22 +323,26 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 		$act = $request->trimValueOf('act');
 		$pageNo = $request->trimValueOf('page');				// ページ番号
 		if (empty($pageNo)) $pageNo = 1;
-		$this->contentType = $request->trimValueOf('content_type');		// 選択中のコンテンツタイプ
+//		$this->contentType = $request->trimValueOf('content_type');		// 選択中のコンテンツタイプ
 
 		$contentTypeName = '';
 		for ($i = 0; $i < count($this->contentTypeArray); $i++){
-			if ($this->contentTypeArray[$i]['value'] == $this->contentType) $contentTypeName = $this->contentTypeArray[$i]['name'];
+			if ($this->contentTypeArray[$i]['value'] == $this->_contentType) $contentTypeName = $this->contentTypeArray[$i]['name'];
 		}
 		
 		// コンテンツ総数を取得
-		switch ($this->contentType)
+		switch ($this->_contentType)
 		{
 			case M3_VIEW_TYPE_CONTENT:				// 汎用コンテンツ
 				$totalCount = self::$_mainDb->getContentCount(self::CONTENT_TYPE, $this->langId);
 				break;
 			case M3_VIEW_TYPE_PRODUCT:				// 商品情報(Eコマース)
+				break;
 			case M3_VIEW_TYPE_BBS:					// BBS
+				break;
 			case M3_VIEW_TYPE_BLOG:				// ブログ
+				$totalCount = self::$_mainDb->getEntryCount($this->langId);
+				break;
 			case M3_VIEW_TYPE_WIKI:				// wiki
 			case M3_VIEW_TYPE_USER:				// ユーザ作成コンテンツ
 			case M3_VIEW_TYPE_EVENT:				// イベント情報
@@ -357,14 +370,18 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 		}
 		
 		// コンテンツリストを取得
-		switch ($this->contentType)
+		switch ($this->_contentType)
 		{
 			case M3_VIEW_TYPE_CONTENT:				// 汎用コンテンツ
 				self::$_mainDb->getContent(self::CONTENT_TYPE, $this->langId, $maxListCount, $pageNo, array($this, 'itemListLoop'));
 				break;
 			case M3_VIEW_TYPE_PRODUCT:				// 商品情報(Eコマース)
+				break;
 			case M3_VIEW_TYPE_BBS:					// BBS
+				break;
 			case M3_VIEW_TYPE_BLOG:				// ブログ
+				self::$_mainDb->getEntry($this->langId, $maxListCount, $pageNo, array($this, 'itemListLoop'));
+				break;
 			case M3_VIEW_TYPE_WIKI:				// wiki
 			case M3_VIEW_TYPE_USER:				// ユーザ作成コンテンツ
 			case M3_VIEW_TYPE_EVENT:				// イベント情報
@@ -375,12 +392,12 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 		
 		// パラメータ引継ぎ
 		$this->tmpl->addVar("_widget", "page_no", $this->convertToDispString($pageNo));		// ページ番号
-		$this->tmpl->addVar("_widget", "content_type", $this->convertToDispString($this->contentType));		// コンテンツタイプ
+		$this->tmpl->addVar("_widget", "content_type", $this->convertToDispString($this->_contentType));		// コンテンツタイプ
 		
 		// その他
 		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
 		$this->tmpl->addVar("_widget", "content_type_name", $this->convertToDispString($contentTypeName));		// コンテンツタイプ名
-		$this->tmpl->addVar("_widget", "config_admin_url", $this->getUrl($this->configAdminUrl));// コンテンツ一覧画面URL
+		$this->tmpl->addVar('_widget', 'config_admin_url', $this->getUrl($this->_baseUrl));
 	}
 	/**
 	 * 選択用メニューを作成
@@ -398,7 +415,7 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 			$row = array(
 				'name' => $name,		// 名前
 				'value' => $value,		// 値
-				'selected' => $this->convertToSelectedString($value, $this->contentType)	// 選択中の項目かどうか
+				'selected' => $this->convertToSelectedString($value, $this->_contentType)	// 選択中の項目かどうか
 			);
 			$this->tmpl->addVars('content_type_list', $row);
 			$this->tmpl->parseTemplate('content_type_list', 'a');
@@ -415,19 +432,44 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 	function itemListLoop($index, $fetchedRow, $param)
 	{
 		$serial = $this->convertToDispString($fetchedRow['cn_serial']);
-		$contentsId = $fetchedRow['cn_id'];		// コンテンツID
+//		$contentsId = $fetchedRow['cn_id'];		// コンテンツID
+		$contentsId = $fetchedRow['contents_id'];		// 共通コンテンツID
+		$contentTitle = $fetchedRow['content_title'];	// コンテンツタイトル
+		$updateUser = $fetchedRow['lu_name'];		// 更新者名
+		$updateDt = $fetchedRow['update_dt'];	// 更新日時
 		
-		// 表示状態
-		$visible = '';
-		if ($fetchedRow['cn_visible']) $visible = 'checked';
-
-		// ユーザ制限
-		$limited = '';
-		if ($fetchedRow['cn_user_limited']) $limited = 'checked';
-
-		// デフォルト時の項目かどうか
-		$default = '';
-		if ($fetchedRow['cn_default']) $default = 'checked';
+		$visible = false;		// 表示状態
+		$limited = false;		// ユーザ制限
+		switch ($this->_contentType)
+		{
+			case M3_VIEW_TYPE_CONTENT:				// 汎用コンテンツ
+				if ($fetchedRow['cn_visible']) $visible = true;
+				if ($fetchedRow['cn_user_limited']) $limited = true;
+				break;
+			case M3_VIEW_TYPE_PRODUCT:				// 商品情報(Eコマース)
+				if ($fetchedRow['pt_visible']) $visible = true;
+				break;
+			case M3_VIEW_TYPE_BBS:					// BBS
+				break;
+			case M3_VIEW_TYPE_BLOG:				// ブログ
+				if ($fetchedRow['be_status'] == 2) $visible = true;
+				if ($fetchedRow['be_user_limited']) $limited = true;
+				break;
+			case M3_VIEW_TYPE_WIKI:				// wiki
+				$visible = true;
+				break;
+			case M3_VIEW_TYPE_USER:				// ユーザ作成コンテンツ
+				if ($fetchedRow['ur_visible']) $visible = true;
+				break;
+			case M3_VIEW_TYPE_EVENT:				// イベント情報
+				if ($fetchedRow['ee_status'] == 2) $visible = true;
+				if ($fetchedRow['ee_user_limited']) $limited = true;
+				break;
+			case M3_VIEW_TYPE_PHOTO:				// フォトギャラリー
+				if ($fetchedRow['ht_visible']) $visible = true;
+				if ($fetchedRow['ht_user_limited']) $limited = true;
+				break;
+		}
 		
 		// 公開状況の設定
 		$now = date("Y/m/d H:i:s");	// 現在日時
@@ -446,8 +488,8 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 		}
 		$statusImg = '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::ICON_SIZE . '" height="' . self::ICON_SIZE . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
 		
-		// プレビュー用URL
-		$previewUrl = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_CONTENT_ID . '=' . $contentsId;
+		// プレビュー
+		$previewUrl = commentCommonDef::createCommentUrl($this->_contentType, $contentsId);
 //		$previewUrl .= '&' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_PREVIEW;// プレビュー用URL
 		$previewImg = $this->getUrl($this->gEnv->getRootUrl() . self::PREVIEW_ICON_FILE);
 		$previewStr = 'プレビュー';
@@ -456,14 +498,13 @@ class admin_commentConfigWidgetContainer extends admin_commentBaseWidgetContaine
 			'index' => $index,													// 項目番号
 			'serial' => $serial,			// シリアル番号
 			'id' => $this->convertToDispString($contentsId),			// ID
-			'name' => $this->convertToDispString($fetchedRow['cn_name']),		// 名前
+			'name' => $this->convertToDispString($contentTitle),		// コンテンツタイトル
 			'lang' => $lang,													// 対応言語
 			'status' => $statusImg,												// 公開状況
-			'update_user' => $this->convertToDispString($fetchedRow['lu_name']),	// 更新者
-			'update_dt' => $this->convertToDispDateTime($fetchedRow['cn_create_dt']),	// 更新日時
-			'visible' => $visible,											// メニュー項目表示制御
-			'limited' => $limited,											// ユーザ制限
-			'default' => $default,											// デフォルト項目
+			'update_user' => $this->convertToDispString($updateUser),	// 更新者
+			'update_dt' => $this->convertToDispDateTime($updateDt),	// 更新日時
+			'visible' => $this->convertToCheckedString($visible),							// 公開状況
+			'limited' => $this->convertToCheckedString($limited),							// ユーザ制限
 
 			'preview_url' => $previewUrl,											// プレビュー用のURL
 			'preview_img' => $previewImg,											// プレビュー用の画像
