@@ -10,13 +10,14 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: commentCommonDef.php 6066 2013-06-03 00:28:13Z fishbone $
+ * @version    SVN: $Id: commentCommonDef.php 6101 2013-06-13 05:30:29Z fishbone $
  * @link       http://www.magic3.org
  */
  
 class commentCommonDef
 {
 	static $_deviceType = 0;	// デバイスタイプ(PC)
+	static $_viewContentType = 'comment';		// 添付ファイル管理用コンテンツタイプ
 	
 	// デフォルト値
 	const DF_VIEW_COUNT		= 100;		// 表示コメント数
@@ -35,37 +36,76 @@ class commentCommonDef
 	const FD_START_DT		= 'cf_start_dt';			// 使用期間(開始)(個別設定可)
 	const FD_END_DT			= 'cf_end_dt';			// 使用期間(終了)(個別設定可)
 	const FD_USER_LIMITED	= 'cf_user_limited';			// 投稿ユーザを制限
+	const FD_NEED_AUTHORIZE	= 'cf_need_authorize';		// 認証が必要かどうか
 	const FD_PERMIT_HTML	= 'cf_permit_html';			// HTMLメッセージ
 	const FD_PERMIT_IMAGE	= 'cf_permit_image';			// 画像あり
+	const FD_AUTOLINK		= 'cf_autolink';			// 自動リンク
 	const FD_USE_TITLE		= 'cf_use_title';			// タイトルあり
 	const FD_USE_AUTHOR		= 'cf_use_author';			// 投稿者名あり
+	const FD_USE_DATE		= 'cf_use_date';			// 投稿日時あり
 	const FD_USE_EMAIL		= 'cf_use_email';			// eメールあり
 	const FD_USE_URL		= 'cf_use_url';				// URLあり
 	const FD_USE_AVATAR		= 'cf_use_avatar';			// アバターあり
 	
+	const COMMENT_PERMA_HEAD	= 'comment-';		// コメントパーマリンク
+	
 	/**
-	 * コメント定義値をDBから取得
+	 * コメントへのリンク作成
 	 *
-	 * @param object $db	DBオブジェクト
-	 * @return array		取得データ
+	 * @param string $contentType		コンテンツタイプ
+	 * @param string $contentsId		共通コンテンツID
+	 * @param int $commentNo			コメント番号(0の場合はコンテンツへのリンク)
+	 * @param string					URL(エラーの場合は空文字列)
 	 */
-/*	static function loadConfig($db)
+	function createCommentUrl($contentType, $contentsId, $commentNo = 0)
 	{
-		$retVal = array();
-
-		// コメント定義を読み込み
-		$ret = $db->getAllConfig($rows);
-		if ($ret){
-			// 取得データを連想配列にする
-			$configCount = count($rows);
-			for ($i = 0; $i < $configCount; $i++){
-				$key = $rows[$i]['bg_id'];
-				$value = $rows[$i]['bg_value'];
-				$retVal[$key] = $value;
-			}
+		global $gEnvManager;
+		$url = '';
+		
+		switch (self::$_deviceType){		// デバイスごとの処理
+			case 0:		// PC
+			default:
+				$url = $gEnvManager->getDefaultPcUrl();
+				break;
+			case 1:		// 携帯
+				$url = $gEnvManager->getDefaultMobileUrl();
+				break;
+			case 2:		// スマートフォン
+				$url = $gEnvManager->getDefaultSmartphoneUrl();
+				break;
 		}
-		return $retVal;
-	}*/
+			
+		switch ($contentType){
+			case M3_VIEW_TYPE_CONTENT:				// 汎用コンテンツ
+				$url .= '?' . M3_REQUEST_PARAM_CONTENT_ID . '=' . $contentsId;
+				break;
+			case M3_VIEW_TYPE_PRODUCT:				// 商品情報(Eコマース)
+				$url .= '?' . M3_REQUEST_PARAM_PRODUCT_ID . '=' . $contentsId;
+				break;
+			case M3_VIEW_TYPE_BBS:					// BBS
+				$url .= '?' . M3_REQUEST_PARAM_BBS_THREAD_ID . '=' . $contentsId;
+				break;
+			case M3_VIEW_TYPE_BLOG:				// ブログ
+				$url .= '?' . M3_REQUEST_PARAM_BLOG_ENTRY_ID . '=' . $contentsId;
+				break;
+			case M3_VIEW_TYPE_WIKI:				// wiki
+				$url .= '?' . $contentsId;
+				break;
+			case M3_VIEW_TYPE_USER:				// ユーザ作成コンテンツ
+				$url .= '?' . M3_REQUEST_PARAM_ROOM_ID . '=' . $contentsId;
+				break;
+			case M3_VIEW_TYPE_EVENT:				// イベント情報
+				$url .= '?' . M3_REQUEST_PARAM_EVENT_ID . '=' . $contentsId;
+				break;
+			case M3_VIEW_TYPE_PHOTO:				// フォトギャラリー
+				$url .= '?' . M3_REQUEST_PARAM_PHOTO_ID . '=' . $contentsId;
+				break;
+		}
+		if (empty($url)) return '';
+
+		if (!empty($commentNo)) $url .= '#' . commentCommonDef::COMMENT_PERMA_HEAD . $commentNo;		// コメントパーマリンク
+		return $url;
+	}
 	/**
 	 * サムネール画像を作成
 	 *
