@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: commentTopWidgetContainer.php 6066 2013-06-03 00:28:13Z fishbone $
+ * @version    SVN: $Id: commentTopWidgetContainer.php 6092 2013-06-11 00:34:26Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getWidgetContainerPath('comment') . '/commentBaseWidgetContainer.php');
@@ -23,6 +23,7 @@ class commentTopWidgetContainer extends commentBaseWidgetContainer
 //	private $currentDay;		// 現在日
 //	private $currentHour;		// 現在時間
 	private $currentPageUrl;			// 現在のページURL
+	private $currentPageRootUrl;
 	private $widgetTitle;			// ウィジェットタイトル
 	private $commentVisible;		// コメントを表示する
 	private $commentAccept;		// コメントを受け付ける
@@ -32,9 +33,11 @@ class commentTopWidgetContainer extends commentBaseWidgetContainer
 	private $useEmail;		// コメント入力項目(Eメールあり)
 	private $useUrl;		// コメント入力項目(URLあり)
 	private $useAvatar;		// コメント入力項目(アバターあり)
+	private $permitHtml;		// HTMLあり
+	private $permitImage;		// 画像あり
+	private $autolink;			// 自動リンク
 	private $addLib = array();		// 追加スクリプト
 	private $avatarSize;		// アバター画像サイズ
-//	const CONTENT_TYPE = 'bg';
 	const COMMENT_ID_SEPARATOR	= ':';			// コメントID作成用セパレータ
 	const DEFAULT_TITLE = 'コメント';		// デフォルトのウィジェットタイトル名
 	const LINK_PAGE_COUNT		= 5;			// リンクページ数
@@ -42,20 +45,14 @@ class commentTopWidgetContainer extends commentBaseWidgetContainer
 	const MESSAGE_NOT_PERMITTED_REFER		= '閲覧は許可されていません';				// コメント閲覧権限がない場合
 	const MESSAGE_NOT_PERMITTED_POST		= '投稿は許可されていません';				// コメント投稿権限がない場合
 	const MESSAGE_NO_COMMENT		= 'コメントは投稿されていません';				// コメントが投稿されていないメッセージ
-
-
-	const COMMENT_PERMA_HEAD	= 'comment-';		// コメントパーマリンク
-	const COMMENT_TITLE_FORMAT		= '「%s」についてのコメント';	// コメント用タイトルフォーマット
-	const COMMENT_TITLE		= ' についてのコメント';	// コメント用タイトル
 	const NO_COMMENT_TITLE = 'タイトルなし';				// 未設定時のコメントタイトル
-	const DEFAULT_VIEW_COUNT	= 10;				// デフォルトの表示記事数
-
-	const COOKIE_LIB = 'jquery.cookie';		// 名前保存用クッキーライブラリ
-
+	const NO_COMMENT_AUTHOR = '投稿者名なし';				// 未設定時のコメント投稿者名
+	const COMMENT_TITLE_FORMAT		= '「%s」についてのコメント';	// コメント用タイトルフォーマット
 	const AVATAR_TITLE_TAIL = 'のアバター';
-	const EDIT_ICON_MIN_POS = 30;			// 編集アイコンの位置
-	const EDIT_ICON_NEXT_POS = 35;			// 編集アイコンの位置
-	
+//	const COMMENT_TITLE		= ' についてのコメント';	// コメント用タイトル
+	const COOKIE_LIB = 'jquery.cookie';		// 名前保存用クッキーライブラリ
+	const PERMALINK_ICON_FILE = '/images/system/permalink.png';		// 「パーマリンク」アイコン
+	const PERMA_BUTTON_ICON_SIZE = 16;				// ボタン用アイコンサイズ
 	/**
 	 * コンストラクタ
 	 */
@@ -90,11 +87,11 @@ class commentTopWidgetContainer extends commentBaseWidgetContainer
 	function _assign($request, &$param)
 	{
 		$contentsId = '';			// 共通コンテンツID
-		$contentType = $this->gPage->getContentType();
-//		$avatarFormat = $this->gInstance->getImageManager()->getDefaultAvatarFormat();		// 画像フォーマット取得
-//		$this->gInstance->getImageManager()->parseImageFormat($avatarFormat, $imageType, $imageAttr, $this->avatarSize);		// 画像情報取得
+		$this->contentType = $this->gPage->getContentType();
+		$avatarFormat = $this->gInstance->getImageManager()->getDefaultAvatarFormat();		// 画像フォーマット取得
+		$this->gInstance->getImageManager()->parseImageFormat($avatarFormat, $imageType, $imageAttr, $this->avatarSize);		// 画像情報取得
 		
-		switch ($contentType){
+		switch ($this->contentType){
 			case M3_VIEW_TYPE_CONTENT:				// 汎用コンテンツ
 				$contentsId = $request->trimValueOf(M3_REQUEST_PARAM_CONTENT_ID);
 				if (empty($contentsId)) $contentsId = $request->trimValueOf(M3_REQUEST_PARAM_CONTENT_ID_SHORT);
@@ -134,9 +131,9 @@ class commentTopWidgetContainer extends commentBaseWidgetContainer
 		}
 		
 		// コメント定義取得
-		$ret = self::$_mainDb->getConfig($contentType, ''/*全体の定義*/, $row);
+		$ret = self::$_mainDb->getConfig($this->contentType, ''/*全体の定義*/, $row);
 		if ($ret){
-			$viewType				= $row[commentCommonDef::FD_VIEW_TYPE];				// コメントタイプ(フラット)
+			$viewType				= $row[commentCommonDef::FD_VIEW_TYPE];				// コメントタイプ(0=フラット、1=ツリー)
 			$viewCount				= $row[commentCommonDef::FD_MAX_COUNT];			// 表示項目数
 			$viewDirection			= $row[commentCommonDef::FD_VIEW_DIRECTION];				// 表示順
 			$this->commentVisible	= $row[commentCommonDef::FD_VISIBLE];		// コメントを表示する
@@ -144,8 +141,10 @@ class commentTopWidgetContainer extends commentBaseWidgetContainer
 			$this->commentAccept	= $row[commentCommonDef::FD_ACCEPT_POST];		// コメントを受け付ける
 			$commentAcceptDefault	= $row[commentCommonDef::FD_ACCEPT_POST_D];		// コメントを受け付ける(個別デフォルト)
 			$userLimited			= $row[commentCommonDef::FD_USER_LIMITED];		// ユーザ制限あり
-			$permitHtml				= $row[commentCommonDef::FD_PERMIT_HTML];		// HTMLあり
-			$permitImage			= $row[commentCommonDef::FD_PERMIT_IMAGE];		// 画像あり
+			$needAuthorize			= $row[commentCommonDef::FD_NEED_AUTHORIZE];		// 認証が必要かどうか
+			$this->permitHtml		= $row[commentCommonDef::FD_PERMIT_HTML];		// HTMLあり
+			$this->permitImage		= $row[commentCommonDef::FD_PERMIT_IMAGE];		// 画像あり
+			$this->autolink			= $row[commentCommonDef::FD_AUTOLINK];			// 自動リンク
 			$maxLength				= $row[commentCommonDef::FD_MAX_LENGTH];			// 文字数
 			$this->useTitle			= $row[commentCommonDef::FD_USE_TITLE];		// タイトルあり
 			$this->useAuthor		= $row[commentCommonDef::FD_USE_AUTHOR];		// 投稿者名あり
@@ -158,7 +157,7 @@ class commentTopWidgetContainer extends commentBaseWidgetContainer
 		}
 		// コンテンツ個別のコメント定義取得
 		// 全体の定義の否定形を最優先する
-		$ret = self::$_mainDb->getConfig($contentType, $contentsId, $row);
+		$ret = self::$_mainDb->getConfig($this->contentType, $contentsId, $row);
 		if ($ret){
 			if ($this->commentVisible) $this->commentVisible	= $row[commentCommonDef::FD_VISIBLE];		// コメントを表示する
 			if ($this->commentAccept) $this->commentAccept		= $row[commentCommonDef::FD_ACCEPT_POST];		// コメントを受け付ける
@@ -176,30 +175,61 @@ class commentTopWidgetContainer extends commentBaseWidgetContainer
 //		$this->currentDay = date("Y/m/d");		// 日
 //		$this->currentHour = (int)date("H");		// 時間
 		$this->currentPageUrl = $this->gEnv->createCurrentPageUrl();// 現在のページURL
-		$sendButtonLabel = 'コメントを投稿';		// 送信ボタンラベル
+		$this->currentPageRootUrl = $this->gEnv->getRootUrlByCurrentPage();
+		$sendButtonLabel = '投稿';		// 送信ボタンラベル
 		$sendStatus = 0;		// 送信状況
-		$inputEnabled = true;			// 入力の許可状態
 		
 		// 入力値取得
 		$act = $request->trimValueOf('act');
 		$pageNo = $request->trimIntValueOf('page', '1');				// ページ番号
-		$title = $request->trimValueOf('title');
-		$author = $request->trimValueOf('author');			// 投稿者名
-		$email = $request->trimValueOf('email');
-		$url = $request->trimValueOf('url');
+		if ($this->useTitle){
+			$title = $request->trimValueOf('title');
+		} else {
+			$title = '';
+		}
+		if ($this->useAuthor){
+			$author = $request->trimValueOf('author');			// 投稿者名
+					
+			// ログイン中はログインユーザ名を取得
+			$userName = $this->gEnv->getCurrentUserName();
+			if (!empty($userName)) $author = $userName;
+		} else {
+			$author = '';
+		}
+		if ($this->useEmail){
+			$email = $request->trimValueOf('email');
+			
+			// ログイン中はログインユーザのEメールを取得
+			$userEmail = $this->gEnv->getCurrentUserEmail();
+			if (!empty($userEmail)) $email = $userEmail;
+		} else {
+			$email = '';
+		}
+		if ($this->useUrl){
+			$url = $request->trimValueOf('url');
+		} else {
+			$url = '';
+		}
 		$comment = $request->trimValueOf('comment');
+		if ($this->permitHtml){			// HTML送信の場合はBBCodeをHTMLに変換
+			$commentHtml = $this->parseComment($comment);
+		}
 		$sendStatus = intval($request->trimValueOf('sendstatus'));			// 送信ステータス
-		if ($sendStatus < 0 || 2 < $sendStatus) $sendStatus = 0;
+		if ($sendStatus < 0 || 1 < $sendStatus) $sendStatus = 0;
 		$postTicket = $request->trimValueOf('ticket');		// POST確認用
 		
 		// コメントIDの確認
 		$isCommentValid = false;
 		$commentId = $request->trimValueOf('commentid');			// コメントID
-		if (!empty($commentId) && $commentId = md5($contentType . self::COMMENT_ID_SEPARATOR . $contentsId)) $isCommentValid = true;
+		if (!empty($commentId) && $commentId = md5($this->contentType . self::COMMENT_ID_SEPARATOR . $contentsId)) $isCommentValid = true;
 		
+		$isInit = false;	// 初期表示かどうか
 		if ($act == 'checkcomment' && $sendStatus == 0){		// コメント確認のとき
 			if (!empty($postTicket) && $postTicket == $request->getSessionValue(M3_SESSION_POST_TICKET) && $isCommentValid){		// 正常なPOST値のとき
 				// 入力チェック
+				if ($this->useAuthor){
+					$this->checkInput($author, '投稿者');
+				}
 				if (empty($maxLength)){		// 空のときは長さのチェックなし
 					$this->checkInput($comment, 'コメント内容');
 				} else {
@@ -212,16 +242,8 @@ class commentTopWidgetContainer extends commentBaseWidgetContainer
 					$this->setGuidanceMsg('この内容でコメントを投稿しますか?');
 				
 					// 入力の変更不可
-					$sendButtonLabel = 'コメントを投稿';		// 送信ボタンラベル
+					$sendButtonLabel = '投稿';		// 送信ボタンラベル
 					$sendStatus = 1;// 送信状況を「確定」に変更
-					$inputEnabled = false;			// 入力の許可状態
-					
-					$this->tmpl->addVar("add_comment", "title_disabled", 'readonly');
-					$this->tmpl->addVar("user_info", "name_disabled", 'readonly');
-					$this->tmpl->addVar("user_info", "email_disabled", 'readonly');
-					$this->tmpl->addVar("add_comment", "url_disabled", 'readonly');
-					$this->tmpl->addVar("add_comment", "body_disabled", 'readonly');
-					$this->tmpl->setAttribute('cancel_button', 'visibility', 'visible');		// キャンセルボタン表示
 				}
 				// ハッシュキー作成
 				$postTicket = md5(time() . $this->gAccess->getAccessLogSerialNo());
@@ -232,37 +254,53 @@ class commentTopWidgetContainer extends commentBaseWidgetContainer
 				
 				$request->unsetSessionValue(M3_SESSION_POST_TICKET);		// セッション値をクリア
 			}
-			
-			// 入力値を戻す
-//			$this->tmpl->addVar("add_comment", "title", $this->convertToDispString($commentTitle));
-//			$this->tmpl->addVar("user_info", "name", $this->convertToDispString($name));
-//			$this->tmpl->addVar("user_info", "email", $this->convertToDispString($email));
-//			$this->tmpl->addVar("add_comment", "url", $this->convertToDispString($url));
-//			$this->tmpl->addVar("add_comment", "body", $this->convertToDispString($comment));
-//			$this->tmpl->addVar("_widget", "entry_id", $this->convertToDispString($this->entryId));		// 記事ID
 		} else if ($act == 'sendcomment' && $sendStatus == 1){	// コメント受信のとき
 			if (!empty($postTicket) && $postTicket == $request->getSessionValue(M3_SESSION_POST_TICKET) && $isCommentValid){		// 正常なPOST値のとき
+				// 入力チェック
+				if ($this->useAuthor){
+					$this->checkInput($author, '投稿者');
+				}
+				if (empty($maxLength)){		// 空のときは長さのチェックなし
+					$this->checkInput($comment, 'コメント内容');
+				} else {
+					$this->checkLength($comment, 'コメント内容', $maxLength);
+				}
+				if ($this->useEmail) $this->checkMailAddress($email, 'Eメール', true);
+				
 				if ($this->getMsgCount() == 0){
 					$ret = false;
 					if (!empty($comment) &&
 						!empty($postTicket) && $postTicket == $request->getSessionValue(M3_SESSION_POST_TICKET)){		// 正常なPOST値のとき
-						// コメントを保存
-						$ret = $this->commentDb->addCommentItem($this->entryId, $this->_langId, $commentTitle, $comment, $url, $name, $email, $this->_userId, $this->now, $newSerial);
-				
-						// 記事更新日を更新
-						if ($ret) $ret = self::$_mainDb->updateEntryDt($this->entryId, $this->_langId);
+						// コメント登録
+						$commentStatus = 0;		// 未設定
+						if (!$needAuthorize) $commentStatus = 2;		// 認証が必要でない場合は自動的に公開
+						
+						// コメント追加タイプ
+						$addType = 0;	// フラット(最後に追加)
+						if ($this->permitHtml){			// HTML送信の場合はBBCodeをHTMLに変換
+							$ret = self::$_mainDb->addComment($addType, $this->contentType, $this->_langId, $contentsId, commentCommonDef::$_deviceType, 0/*親コメントシリアル*/, 
+													$title, $commentHtml, $url, $author, $email, $commentStatus, $newSerial);
+						} else {
+							$ret = self::$_mainDb->addComment($addType, $this->contentType, $this->_langId, $contentsId, commentCommonDef::$_deviceType, 0/*親コメントシリアル*/, 
+													$title, $comment, $url, $author, $email, $commentStatus, $newSerial);
+						}
 					}
 					if ($ret){
 						$this->setGuidanceMsg('コメントを投稿しました');
+						
+						// 入力値をクリア
+						$title = '';
+						$comment = '';
+						$commentHtml = '';
+						$url = '';
+						$author = '';
+						$email = '';
 					} else {
 						$this->setUserErrorMsg('コメントの投稿に失敗しました');
 					}
-				//$request->unsetSessionValue(M3_SESSION_POST_TICKET);		// セッション値をクリア
-					// 項目を入力不可に設定
-					$inputEnabled = false;			// 入力の許可状態
 
 					// 送信ステータスを更新
-					$sendStatus = 2;
+					$sendStatus = 0;
 					
 					$request->unsetSessionValue(M3_SESSION_POST_TICKET);		// セッション値をクリア
 				} else {		// 送信時入力エラーの場合は初期画面に戻す
@@ -281,6 +319,8 @@ class commentTopWidgetContainer extends commentBaseWidgetContainer
 			}
 		} else if ($act == 'sendcancel' && $sendStatus == 1){	// コメントキャンセルのとき
 			if (!empty($postTicket) && $postTicket == $request->getSessionValue(M3_SESSION_POST_TICKET) && $isCommentValid){		// 正常なPOST値のとき
+				$this->setGuidanceMsg('コメントをキャンセルしました');
+				
 				// 送信ステータスを更新
 				$sendStatus = 0;
 
@@ -294,6 +334,8 @@ class commentTopWidgetContainer extends commentBaseWidgetContainer
 				$request->unsetSessionValue(M3_SESSION_POST_TICKET);		// セッション値をクリア
 			}
 		} else {
+			$isInit = true;	// 初期表示かどうか
+			
 			// 送信ステータスを初期化
 			$sendStatus = 0;
 				
@@ -303,29 +345,30 @@ class commentTopWidgetContainer extends commentBaseWidgetContainer
 		}
 		
 		// タイトル作成
-		$this->widgetTitle = $this->createTitle($contentType, $contentsId);
+		$this->widgetTitle = $this->createTitle($this->contentType, $contentsId);
 		
 		// ##### コメントを表示 #####
 		$showComment = false;		// コメント表示するかどうか
 		if (!$userLimited || ($userLimited && $this->gEnv->isCurrentUserLogined())){		// ユーザ制限なし、または、ユーザ制限ありでログイン済みの場合
 			if ($sendStatus == 0){		// 初期表示の場合はすべてのコメントを表示
-				//$this->tmpl->setAttribute('show_comment', 'visibility', 'visible');		// 既存コメントを表示
-						
+				//$this->tmpl->setAttribute('show_comment_list', 'visibility', 'visible');		// 既存コメントを表示
+				// コメント表示項目設定
+				if ($viewType == 1) $this->tmpl->setAttribute('show_reply', 'visibility', 'visible');		// 「返信」ボタン表示
+				if ($this->useTitle) $this->tmpl->setAttribute('show_title', 'visibility', 'visible');	// タイトル
+				if ($this->useAvatar) $this->tmpl->setAttribute('show_avatar', 'visibility', 'visible');	// アバター
+				
 				// コメント総数取得
-				$totalCount = self::$_mainDb->getCommentCount($contentType, $this->_langId, $contentsId, true/*公開コメントのみ*/);
+				$totalCount = self::$_mainDb->getCommentCount($this->contentType, $this->_langId, $contentsId, true/*公開コメントのみ*/);
 				$pageLink = $this->createPageLink($pageNo, $totalCount, $viewCount, $this->currentPageUrl);
 		
 				// コメント取得
-				self::$_mainDb->getComment($contentType, $this->_langId, $contentsId, $viewCount, $pageNo, $viewDirection, array($this, 'itemsLoop'));
+				self::$_mainDb->getComment($this->contentType, $this->_langId, $contentsId, $viewCount, $pageNo, $viewDirection, array($this, 'itemsLoop'));
 			
 				// コメントがない場合はリストを非表示
 				//if (!$this->isExistsComment) $this->tmpl->setAttribute('comment_list', 'visibility', 'hidden');
-				if ($this->isExistsComment) $this->tmpl->setAttribute('show_comment', 'visibility', 'visible');		// 既存コメントを表示
+				if ($this->isExistsComment) $this->tmpl->setAttribute('show_comment_list', 'visibility', 'visible');		// 既存コメントを表示
 			} else {
 				// 初期表示以外の場合はリプライ先のコメントのみ表示
-				
-				// コメント入力エリアをトップに表示
-				$this->tmpl->setAttribute('scrollup_comment', 'visibility', 'visible');
 			}
 			
 			$showComment = true;		// コメント表示するかどうか
@@ -337,30 +380,75 @@ class commentTopWidgetContainer extends commentBaseWidgetContainer
 		if ($showComment && $this->commentAccept){
 			$this->tmpl->setAttribute('add_comment', 'visibility', 'visible');		// コメント投稿欄を表示
 			
+			// 入力値を戻す
 			if ($this->useTitle){
 				$this->tmpl->setAttribute('input_title', 'visibility', 'visible');		// タイトルあり
+				$this->tmpl->addVar("input_title", "title", $this->convertToDispString($title));
 			}
 			if ($this->useAuthor){
 				$this->tmpl->setAttribute('input_author', 'visibility', 'visible');		// 投稿者名あり
+				$this->tmpl->addVar("input_author", "author", $this->convertToDispString($author));
+				
+				// ログイン中はログインユーザ名を表示
+				if ($this->gEnv->isCurrentUserLogined()){
+					$this->tmpl->addVar("input_author", "author_disabled", 'readonly');
+					$this->tmpl->setAttribute('update_cookie_author', 'visibility', 'hidden');
+					$this->tmpl->setAttribute('init_cookie_author', 'visibility', 'hidden');
+				}
 			}
 			if ($this->useEmail){
 				$this->tmpl->setAttribute('input_email', 'visibility', 'visible');		// Eメールあり
+				$this->tmpl->addVar("input_email", "email", $this->convertToDispString($email));
+				
+				// ログイン中はログインユーザのEメールを表示
+				$userEmail = $this->gEnv->getCurrentUserEmail();
+				if ($this->gEnv->isCurrentUserLogined() && !empty($userEmail)){		// Eメールが設定されている場合のみ
+					$this->tmpl->addVar("input_email", "email_disabled", 'readonly');
+					$this->tmpl->setAttribute('update_cookie_email', 'visibility', 'hidden');
+					$this->tmpl->setAttribute('init_cookie_email', 'visibility', 'hidden');
+				}
 			}
 			if ($this->useUrl){
 				$this->tmpl->setAttribute('input_url', 'visibility', 'visible');		// URLあり
+				$this->tmpl->addVar("input_url", "url", $this->convertToDispString($url));
 			}
-			
+
 			//if ($this->useAvatar) $this->tmpl->setAttribute('input_title', 'visibility', 'visible');		// アバターあり
 			
-			/*
-			if (!self::$_configArray[commentCommonDef::CF_COMMENT_USER_LIMITED]){	// ユーザ制限なしのときは名前、メールアドレスを表示
-				$this->tmpl->setAttribute('user_info', 'visibility', 'visible');
+			if ($sendStatus == 1){		// 確認画面のとき
+				$this->tmpl->addVar("input_title", "title_disabled", 'readonly');
+				$this->tmpl->addVar("input_author", "author_disabled", 'readonly');
+				$this->tmpl->addVar("input_email", "email_disabled", 'readonly');
+				$this->tmpl->addVar("input_url", "url_disabled", 'readonly');
+				$this->tmpl->addVar("input_comment", "comment_disabled", 'readonly');
+				$this->tmpl->setAttribute('cancel_button', 'visibility', 'visible');		// キャンセルボタン表示
+				
+				// クッキー停止
+				$this->tmpl->setAttribute('update_cookie_author', 'visibility', 'hidden');
+				$this->tmpl->setAttribute('init_cookie_author', 'visibility', 'hidden');
+				$this->tmpl->setAttribute('update_cookie_email', 'visibility', 'hidden');
+				$this->tmpl->setAttribute('init_cookie_email', 'visibility', 'hidden');
+			}
+
+			// HTML入力用の設定
+			if ($this->permitHtml){
+				if ($sendStatus == 0){		// 初期状態のとき
+					$this->tmpl->setAttribute('input_comment', 'visibility', 'visible');		// コメント入力フィールド表示
+					
+					$this->tmpl->setAttribute('show_wysiwyg', 'visibility', 'visible');		// wysiwygエディター表示
+					$this->addLib[] = ScriptLibInfo::LIB_CKEDITOR;		// CKEditorライブラリを追加
+				} else {
+					$this->tmpl->setAttribute('show_comment', 'visibility', 'visible');
+					$this->tmpl->addVar('show_comment', 'comment_html', $commentHtml);			// HTMLコメント
+					$this->tmpl->addVar('show_comment', 'comment', $this->convertToDispString($comment));			// コメントソース
+				}
+			} else {
+				$this->tmpl->setAttribute('input_comment', 'visibility', 'visible');	// コメント入力フィールド表示
+				$this->tmpl->addVar('input_comment', 'comment', $this->convertToDispString($comment));			// コメントソース
 			}
-			$this->tmpl->setAttribute('add_comment', 'visibility', 'visible');
-			*/
 
 			// コメントID作成
-			$commentId = md5($contentType . self::COMMENT_ID_SEPARATOR . $contentsId);			// コメントID作成用セパレータ
+			$commentId = md5($this->contentType . self::COMMENT_ID_SEPARATOR . $contentsId);			// コメントID作成用セパレータ
 			
 			$this->tmpl->addVar("add_comment", "send_button_label", $sendButtonLabel);// 送信ボタンラベル
 			$this->tmpl->addVar("add_comment", "send_status", $sendStatus);// 送信状況
@@ -368,8 +456,14 @@ class commentTopWidgetContainer extends commentBaseWidgetContainer
 			$this->tmpl->addVar("add_comment", "ticket", $postTicket);				// 画面確認用
 			$this->tmpl->addVar("add_comment", "comment_id", $commentId);				// コメントID
 			
+			//if ($sendStatus != 0 || $this->getMsgCount() > 0){		// 初期状態以外または入力エラーがあるとき
+			if (!$isInit){		// 初期表示以外のとき
+				// コメント入力エリアをトップに表示
+				$this->tmpl->setAttribute('scrollup_comment', 'visibility', 'visible');
+			}
+				
 			// 名前保存用のスクリプトライブラリ追加
-			$this->tmpl->setAttribute('init_cookie', 'visibility', 'visible');
+			$this->tmpl->setAttribute('init_form', 'visibility', 'visible');
 			$this->tmpl->setAttribute('update_cookie', 'visibility', 'visible');
 			$this->addLib[] = self::COOKIE_LIB;
 			
@@ -382,8 +476,9 @@ class commentTopWidgetContainer extends commentBaseWidgetContainer
 			$this->message = self::MESSAGE_NO_COMMENT;
 		}
 		
-		// 初期表示の場合はメッセージを表示
-		if ($sendStatus == 0 && !empty($this->message)){
+		// 初期表示の場合で入力エラーメッセージがない場合はメッセージを表示
+		//if ($sendStatus == 0 && $this->getMsgCount() == 0 && !empty($this->message)){
+		if ($isInit && !empty($this->message)){
 			$this->tmpl->setAttribute('message', 'visibility', 'visible');
 			$this->tmpl->addVar("message", "message", $this->convertToDispString($this->message));
 		}
@@ -471,55 +566,62 @@ class commentTopWidgetContainer extends commentBaseWidgetContainer
 	 */
 	function itemsLoop($index, $fetchedRow)
 	{
-		$permalink = '#' . self::COMMENT_PERMA_HEAD . $fetchedRow['bo_no'];		// コメントパーマリンク
-		$commentTitle = $fetchedRow['bo_name'];			// コメントタイトル
-		if (empty($commentTitle)) $commentTitle = self::NO_COMMENT_TITLE;
-		$commentTitle = '<a href="' . $permalink . '">' . $this->convertToDispString($commentTitle) . '</a>';
-	
-		// コメント投稿ユーザ名
-		if (self::$_configArray[commentCommonDef::CF_COMMENT_USER_LIMITED]){	// ユーザ制限のときはログインユーザ名を取得
-			$userName = $this->convertToDispString($fetchedRow['lu_name']);
-		} else {
-			$userName = $this->convertToDispString($fetchedRow['bo_user_name']);	// 入力値を使用
+		$contentsId = $fetchedRow['cm_contents_id'];		// 共通コンテンツID
+		$permaLink = commentCommonDef::COMMENT_PERMA_HEAD . $fetchedRow['cm_no'];		// コメントパーマリンク
+		$titleTag = '';
+		if ($this->useTitle){
+			$commentTitle = $fetchedRow['cm_title'];			// コメントタイトル
+			if (empty($commentTitle)) $commentTitle = self::NO_COMMENT_TITLE;
+			$titleTag = '<a name="' . $permaLink . '" href="#' . $permaLink . '">' . $this->convertToDispString($commentTitle) . '</a>';
 		}
-		$url = $fetchedRow['bo_url'];
-		if (!empty($url)) $url = '<a href="' . $this->convertUrlToHtmlEntity($url) . '" target="_blank">URL</a>';
-		$comment = '<div class="blog_comment_body">' . $this->convertToPreviewText($this->convertToDispString($fetchedRow['bo_html'])) . '</div>';		// 改行コードをbrタグに変換
+		$permaUrl = commentCommonDef::createCommentUrl($this->contentType, $contentsId, $fetchedRow['cm_no']);
+		$permaTag = '<a href="' . $this->convertUrlToHtmlEntity($permaUrl) . '"><img src="' . $this->getUrl($this->gEnv->getRootUrl() . self::PERMALINK_ICON_FILE) . 
+						'" width="' . self::PERMA_BUTTON_ICON_SIZE . '" height="' . self::PERMA_BUTTON_ICON_SIZE . '" title="パーマリンク" alt="パーマリンク" style="border:none;margin:0;padding:0;" /></a>';
+						
+		// コメント投稿ユーザ名
+		if ($this->useAuthor){
+			$userName = $fetchedRow['lu_name'];
+			if (empty($userName)) $userName = $fetchedRow['cm_author'];
+		}
+		if (empty($userName)) $userName = self::NO_COMMENT_AUTHOR;
 	
 		// アバター
-		$avatarUrl = $this->gInstance->getImageManager()->getAvatarUrl($fetchedRow['lu_avatar']);
-		$avatarTitle = $this->convertToDispString($userName) . self::AVATAR_TITLE_TAIL;
-		$avatarTag = '<img src="' . $this->getUrl($avatarUrl) . '" width="' . $this->avatarSize . '" height="' . $this->avatarSize . 
-						'" border="0" alt="' . $avatarTitle . '" title="' . $avatarTitle . '" />';
+		$avatarTag = '';
+		if ($this->useAvatar){
+			$avatarUrl = $this->gInstance->getImageManager()->getAvatarUrl($fetchedRow['lu_avatar']);
+			$avatarTitle = $this->convertToDispString($userName) . self::AVATAR_TITLE_TAIL;
+			$avatarTag = '<img src="' . $this->getUrl($avatarUrl) . '" width="' . $this->avatarSize . '" height="' . $this->avatarSize . 
+							'" border="0" alt="' . $avatarTitle . '" title="' . $avatarTitle . '" />';
+		}
 
-		// Magic3マクロ変換
-		// あらかじめ「CM_」タグをすべて取得する?
-		$contentParam = array();
-		$contentParam[M3_TAG_MACRO_COMMENT_AUTHOR] = $this->convertToDispString($userName);			// コンテンツ置換キー(著者)
-		$contentParam[M3_TAG_MACRO_COMMENT_DATE] = $this->timestampToDate($fetchedRow['bo_regist_dt']);		// コンテンツ置換キー(登録日)
-		$contentParam[M3_TAG_MACRO_COMMENT_TIME] = $this->timestampToTime($fetchedRow['bo_regist_dt']);		// コンテンツ置換キー(登録時)
-		$contentParam[M3_TAG_MACRO_AVATAR] = $avatarTag;
-		$contentParam[M3_TAG_MACRO_TITLE] = $commentTitle;
-		$contentParam[M3_TAG_MACRO_BODY] = $comment;
-		$contentParam[M3_TAG_MACRO_URL] = $url;
-		$commentText = $this->createComment($contentParam);
-
-		$commentRow = array(
-			'comment'		=> $commentText			// コメント内容
-		);
-		$this->tmpl->addVars('comment_list', $commentRow);
-		$this->tmpl->parseTemplate('comment_list', 'a');
-
-
-		// コメントへのリンク
-		$commentLink = '';
-		if ($this->viewMode != 10 && $this->commentAccept){	// 記事単体表示でコメントを表示する場合
-			$commentLink = '<strong><a href="' . $this->convertUrlToHtmlEntity($linkUrl . '#comment') . '" >コメント(' . $commentCount . ')</a></strong>';	// コメントへのリンク
+		// URL
+		$urlTag = '';
+		if ($this->useUrl){
+			$url = $fetchedRow['cm_url'];
+			if (!empty($url)) $urlTag = '<br />URL: <a href="' . $this->convertUrlToHtmlEntity($url) . '" target="_blank">' . $this->convertToDispString($url) . '</a>';
 		}
 		
+		// コメント内容
+		if ($this->permitHtml){			// HTMLコメントの場合
+			// Magic3マクロの変換
+			//$commentTag = $this->convertM3ToHtml($fetchedRow['cm_message'], true/*改行コーをbrタグに変換*/);
+			$commentTag = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->currentPageRootUrl, $fetchedRow['cm_message']);// アプリケーションルートを変換
+		} else {
+			$commentTag = $this->convertToPreviewText($this->convertToDispString($fetchedRow['cm_message']));// 改行コードをbrタグに変換
+		}
+		if ($this->autolink){		// 自動リンクの場合
+			$commentTag = preg_replace("/(https?):\/\/([\w;\/\?:\@&=\+\$,\-\.!~\*'\(\)%#]+)/", "<a href=\"$1://$2\" target=\"_blank\">$1://$2</a>", $commentTag);
+		}
+
 		$row = array(
-			'entry' => $entryText,	// 投稿記事
-			'button_list' => $buttonList	// 記事編集ボタン
+			'title'	=> $titleTag,		// タイトル
+			'avatar' => $avatarTag,			// アバター
+			'author' => $this->convertToDispString($userName),	// 投稿者名
+			'date' => $this->timestampToDate($fetchedRow['cm_create_dt']),		// コメント投稿日(日付)
+			'time' => $this->timestampToTime($fetchedRow['cm_create_dt']),		// コメント投稿日(時間)
+			'permalink' => $permaTag,			// パーマリンクアイコン
+			'url'	=> $urlTag,		// URL
+			'comment' => $commentTag	// コメント内容
 		);
 		$this->tmpl->addVars('comment_list', $row);
 		$this->tmpl->parseTemplate('comment_list', 'a');
@@ -572,58 +674,15 @@ class commentTopWidgetContainer extends commentBaseWidgetContainer
 		return $pageLink;
 	}
 	/**
-	 * 詳細コンテンツを作成
+	 * BBCodeのコメントを解析し、HTMLに変換
 	 *
-	 * @param int $viewMode				表示モード
-	 * @param array	$contentParam		コンテンツ作成用パラメータ
-	 * @return string			作成コンテンツ
+	 * @param string $src		コメント入力
+	 * @return string			HTML変換したコメント
 	 */
-	function createDetailContent($viewMode, $contentParam)
+	function parseComment($src)
 	{
-		static $initContentText;
-		
-		if (!isset($initContentText)){
-			if ($viewMode == 10){		// 記事単体表示の場合
-				$initContentText = self::$_configArray[commentCommonDef::CF_LAYOUT_ENTRY_SINGLE];			// コンテンツレイアウト(記事詳細)
-			} else {
-				$initContentText = self::$_configArray[commentCommonDef::CF_LAYOUT_ENTRY_LIST];			// コンテンツレイアウト(記事一覧)
-			}
-		}
-		
-		// コンテンツを作成
-		$contentText = $initContentText;
-		$keys = array_keys($contentParam);
-		for ($i = 0; $i < count($keys); $i++){
-			$key = $keys[$i];
-			$value = str_replace('\\', '\\\\', $contentParam[$key]);	// ##### (注意)preg_replaceで変換値のバックスラッシュが解釈されるので、あらかじめバックスラッシュを2重化しておく必要がある
-			
-			$pattern = '/' . preg_quote(M3_TAG_START . $key) . ':?(.*?)' . preg_quote(M3_TAG_END) . '/u';
-			$contentText = preg_replace($pattern, $value, $contentText);
-		}
-		return $contentText;
-	}
-	/**
-	 * コメントを作成
-	 *
-	 * @param array	$contentParam		コンテンツ作成用パラメータ
-	 * @return string			作成コンテンツ
-	 */
-	function createComment($contentParam)
-	{
-		static $initContentText;
-		if (!isset($initContentText)) $initContentText = self::$_configArray[commentCommonDef::CF_LAYOUT_COMMENT_LIST];			// コンテンツレイアウト(コメント一覧)
-		
-		// コンテンツを作成
-		$contentText = $initContentText;
-		$keys = array_keys($contentParam);
-		for ($i = 0; $i < count($keys); $i++){
-			$key = $keys[$i];
-			$value = str_replace('\\', '\\\\', $contentParam[$key]);	// ##### (注意)preg_replaceで変換値のバックスラッシュが解釈されるので、あらかじめバックスラッシュを2重化しておく必要がある
-			
-			$pattern = '/' . preg_quote(M3_TAG_START . $key) . ':?(.*?)' . preg_quote(M3_TAG_END) . '/u';
-			$contentText = preg_replace($pattern, $value, $contentText);
-		}
-		return $contentText;
+		$commentHtml = $this->gInstance->getTextConvManager()->convBBCodeToHtml($src, true);
+		return $commentHtml;
 	}
 }
 ?>
