@@ -10,7 +10,7 @@
  * @author     株式会社 毎日メディアサービス
  * @copyright  Copyright 2010-2013 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: custom_searchWidgetContainer.php 5910 2013-04-06 23:14:10Z fishbone $
+ * @version    SVN: $Id: custom_searchWidgetContainer.php 5969 2013-04-29 13:16:04Z fishbone $
  * @link       http://www.m-media.co.jp
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -32,9 +32,6 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 	const CONTENT_SIZE = 200;			// 検索結果コンテンツの文字列最大長
 	const SEARCH_LIST_CONTENT_ID = 'SEARCH_LIST';	// 検索一覧に表示するコンテンツのID
 	const DEFAULT_SEARCH_ACT = 'custom_search';		// 検索実行処理
-	const CONTENT_TYPE_CONTENT = 'ct';			// コンテンツタイプ(汎用コンテンツ)
-	const CONTENT_TYPE_USER = 'uc';			// コンテンツタイプ(ユーザ作成コンテンツ)
-	const CONTENT_TYPE_BLOG = 'bg';			// コンテンツタイプ(ブログ)
 
 	/**
 	 * コンストラクタ
@@ -86,6 +83,10 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 			return;
 		}
 		
+		// ログインユーザでないときは、ユーザ制限のない項目だけ表示
+		$isAll = false;
+		if ($this->gEnv->isCurrentUserLogined()) $isAll = true;
+		
 		$name = $targetObj->name;// 定義名
 		$this->resultCount	= intval($targetObj->resultCount);			// 表示項目数
 		if ($this->resultCount <= 0) $this->resultCount = self::DEFAULT_SEARCH_COUNT;
@@ -95,6 +96,10 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 		$isTargetContent = $targetObj->isTargetContent;		// 汎用コンテンツを検索対象とするかどうか
 		$isTargetUser = $targetObj->isTargetUser;			// ユーザ作成コンテンツを検索対象とするかどうか
 		$isTargetBlog = $targetObj->isTargetBlog;			// ブログ記事を検索対象とするかどうか
+		$isTargetProduct = $targetObj->isTargetProduct;			// 商品情報を検索対象とするかどうか
+		$isTargetEvent = $targetObj->isTargetEvent;			// イベント情報を検索対象とするかどうか
+		$isTargetBbs = $targetObj->isTargetBbs;			// BBSを検索対象とするかどうか
+		$isTargetPhoto = $targetObj->isTargetPhoto;			// フォトギャラリーを検索対象とするかどうか
 		$searchTemplate = $targetObj->searchTemplate;		// 検索用テンプレート
 		if (!empty($targetObj->fieldInfo)) $this->fieldInfoArray = $targetObj->fieldInfo;			// 項目定義
 		$searchFormId = $this->gEnv->getCurrentWidgetId() . '_' . $configId . '_form';		// フォームのID
@@ -157,13 +162,17 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 			} else {
 				// ##### 検索実行の場合 #####
 				// 総数を取得
-				$totalCount = $this->db->searchContentsCountByKeyword($parsedKeywords, $selectCategory, $this->langId, $isTargetContent, $isTargetUser, $isTargetBlog);
+//				$totalCount = $this->db->searchContentsCountByKeyword($parsedKeywords, $selectCategory, $this->langId, $isAll, $isTargetContent, $isTargetUser, $isTargetBlog,
+//								$isTargetProduct, $isTargetEvent, $isTargetBbs, $isTargetPhoto);
+				$totalCount = $this->db->searchContentsByKeyword(0/*項目数取得*/, 0/*ダミー*/, $parsedKeywords, $selectCategory, $this->langId, $isAll, $isTargetContent, $isTargetUser, $isTargetBlog,
+								$isTargetProduct, $isTargetEvent, $isTargetBbs, $isTargetPhoto);
 
 				// リンク文字列作成、ページ番号調整
 				$pageLink = $this->createPageLink($pageNo, $totalCount, $this->resultCount, $this->currentPageUrl . '&act=' . self::DEFAULT_SEARCH_ACT . '&keyword=' . urlencode($keyword));
 				
 				// 検出項目を表示
-				$this->db->searchContentsByKeyword($this->resultCount, $pageNo, $parsedKeywords, $selectCategory, $this->langId, $isTargetContent, $isTargetUser, $isTargetBlog, array($this, 'searchItemsLoop'));
+				$this->db->searchContentsByKeyword($this->resultCount, $pageNo, $parsedKeywords, $selectCategory, $this->langId, $isAll, $isTargetContent, $isTargetUser, $isTargetBlog, 
+								$isTargetProduct, $isTargetEvent, $isTargetBbs, $isTargetPhoto, array($this, 'searchItemsLoop'));
 				
 				if ($this->isExistsViewData){
 					// ページリンクを埋め込む
@@ -310,10 +319,10 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 	{
 		// コンテンツへのリンクを生成
 		$linkUrl = '';
-		$bodyHtml = '';
+		$summary = '';		// コンテンツ概要
 		$contentType = $fetchedRow['type'];
 		switch ($contentType){
-			case self::CONTENT_TYPE_CONTENT:		// 汎用コンテンツの場合
+			case M3_VIEW_TYPE_CONTENT:		// 汎用コンテンツの場合
 				$contentId = $fetchedRow['id'];
 				
 				// コンテンツへのリンクを作成
@@ -338,10 +347,10 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 					} else {
 						$content = substr($content, 0, self::CONTENT_SIZE) . '...';
 					}
-					$bodyHtml = $content;
+					$summary = $content;
 				}
 				break;
-			case self::CONTENT_TYPE_USER:		// ユーザ作成コンテンツの場合
+			case M3_VIEW_TYPE_USER:		// ユーザ作成コンテンツの場合
 				$roomId = $fetchedRow['id'];
 				$groupId = $fetchedRow['group_id'];			// ルームの所属グループ
 				
@@ -399,7 +408,7 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 						} else {
 							$content = substr($content, 0, self::CONTENT_SIZE) . '...';
 						}
-						$bodyHtml = $content;
+						$summary = $content;
 					}
 				} else {		// 検索一覧用データがあるとき
 					$contentInfo = $contentArray[$searchListItemId];
@@ -413,10 +422,10 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 					} else {
 						$contentData = '';
 					}
-					$bodyHtml = $contentData;
+					$summary = $contentData;
 				}
 				break;
-			case self::CONTENT_TYPE_BLOG:			// ブログコンテンツの場合
+			case M3_VIEW_TYPE_BLOG:			// ブログコンテンツの場合
 				$entryId = $fetchedRow['id'];
 				
 				// ブログ記事へのリンクを作成
@@ -437,7 +446,112 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 					} else {
 						$content = substr($content, 0, self::CONTENT_SIZE) . '...';
 					}
-					$bodyHtml = $content;
+					$summary = $content;
+				}
+				break;
+			case M3_VIEW_TYPE_PRODUCT:			// 商品情報の場合
+				$productId = $fetchedRow['id'];
+				
+				// 商品情報へのリンクを作成
+				$linkUrl = $this->getUrl($this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_PRODUCT_ID . '=' . $productId, true/*リンク用*/);
+
+				// 商品情報を取得
+				$ret = $this->db->getProductByProductId($productId, $this->langId, $row);
+				if ($ret){
+					$summary = $row['pt_description_short'];
+					if (empty($summary)){
+						// テキストに変換。HTMLタグ削除。
+						$content = $this->gInstance->getTextConvManager()->htmlToText($row['pt_description']);
+	
+						// 検索結果用にテキストを詰める。改行、タブ、スペース削除。
+						$content = str_replace(array("\r", "\n", "\t", " "), '', $content);
+	
+						// 文字列長を修正
+						if (function_exists('mb_strimwidth')){
+							$content = mb_strimwidth($content, 0, self::CONTENT_SIZE, '…');
+						} else {
+							$content = substr($content, 0, self::CONTENT_SIZE) . '...';
+						}
+						$summary = $content;
+					}
+				}
+				break;
+			case M3_VIEW_TYPE_EVENT:			// イベント情報の場合
+				$eventId = $fetchedRow['id'];
+				
+				// イベント情報へのリンクを作成
+				$linkUrl = $this->getUrl($this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_EVENT_ID . '=' . $eventId, true/*リンク用*/);
+
+				// イベント情報を取得
+				$ret = $this->db->getEvent($eventId, $this->langId, $row);
+				if ($ret){
+					$summary = $row['ee_summary'];
+					if (empty($summary)){
+						// テキストに変換。HTMLタグ削除。
+						$content = $this->gInstance->getTextConvManager()->htmlToText($row['ee_html']);
+	
+						// 検索結果用にテキストを詰める。改行、タブ、スペース削除。
+						$content = str_replace(array("\r", "\n", "\t", " "), '', $content);
+	
+						// 文字列長を修正
+						if (function_exists('mb_strimwidth')){
+							$content = mb_strimwidth($content, 0, self::CONTENT_SIZE, '…');
+						} else {
+							$content = substr($content, 0, self::CONTENT_SIZE) . '...';
+						}
+						$summary = $content;
+					}
+				}
+				break;
+			case M3_VIEW_TYPE_BBS:			// BBSスレッド情報の場合
+				$threadId = $fetchedRow['id'];
+				
+				// フォト情報へのリンクを作成
+				$linkUrl = $this->getUrl($this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_BBS_THREAD_ID . '=' . $threadId, true/*リンク用*/);
+
+				// フォト情報を取得
+				$ret = $this->db->getBbsThread($threadId, $row);
+				if ($ret){
+					// テキストに変換。HTMLタグ削除。
+					$content = $this->gInstance->getTextConvManager()->htmlToText($row['te_message']);
+
+					// 検索結果用にテキストを詰める。改行、タブ、スペース削除。
+					$content = str_replace(array("\r", "\n", "\t", " "), '', $content);
+
+					// 文字列長を修正
+					if (function_exists('mb_strimwidth')){
+						$content = mb_strimwidth($content, 0, self::CONTENT_SIZE, '…');
+					} else {
+						$content = substr($content, 0, self::CONTENT_SIZE) . '...';
+					}
+					$summary = $content;
+				}
+				break;
+			case M3_VIEW_TYPE_PHOTO:			// フォト情報の場合
+				$photoId = $fetchedRow['id'];
+				
+				// フォト情報へのリンクを作成
+				$linkUrl = $this->getUrl($this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_PHOTO_ID . '=' . $photoId, true/*リンク用*/);
+
+				// フォト情報を取得
+				$ret = $this->db->getPhoto($photoId, $this->langId, $row);
+				if ($ret){
+					$summary = $row['ht_summary'];
+					if (empty($summary)){
+						// テキストに変換。HTMLタグ削除。
+						$content = $this->gInstance->getTextConvManager()->htmlToText($row['ht_description']);
+	
+						// 検索結果用にテキストを詰める。改行、タブ、スペース削除。
+						$content = str_replace(array("\r", "\n", "\t", " "), '', $content);
+	
+						// 文字列長を修正
+						if (function_exists('mb_strimwidth')){
+							$content = mb_strimwidth($content, 0, self::CONTENT_SIZE, '…');
+						} else {
+							$content = substr($content, 0, self::CONTENT_SIZE) . '...';
+						}
+						$summary = $content;
+					}
 				}
 				break;
 			default:
@@ -448,7 +562,7 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 
 		$row = array(
 			'title' => $titleLink,			// タイトル
-			'body' => $bodyHtml			// コンテンツ内容
+			'body' => $summary			// コンテンツ概要
 		);
 		$this->tmpl->addVars('result_list', $row);
 		$this->tmpl->parseTemplate('result_list', 'a');
